SystemOrganization addCategory: #'Seaside-Development-Core'!
SystemOrganization addCategory: #'Seaside-Development-Plugins'!
SystemOrganization addCategory: #'Seaside-Development-Filter'!

!WADispatcher methodsFor: '*seaside-development' stamp: 'lr 2/10/2008 15:45'!
configurationComponent
	^ WADispatcherEditor on: self! !

WAErrorHandler subclass: #WADebugErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADebugErrorHandler commentStamp: 'pmm 5/27/2007 21:47' prior: 0!
I am like WAErrorHandler except that I open a debugger in the image for errors and warnings (not for internal errors).!

!WADebugErrorHandler methodsFor: 'actions' stamp: 'jf 11/12/2008 01:58'!
debugAndResume: anException
	self open: anException.

	"If the user closes the debugger, the process is terminated and the stack unwound.
	There was previously an #ifCurtailed: block around the #open: call above to try to
	catch the process termination so we could display a nice error page but this also
	ended up being called when the user restarted a context in the debugger.
	
	If they Proceed in the debugger, behaviour is platform-dependent. Currently, VW
	should resume the signaling context, so this method will not continue past the call
	to #open:. Squeak currently resumes the context that opened the Debugger, which
	results in the call to #open: returning."

	^ anException isResumable
		ifTrue: [ anException resume ]
		ifFalse: [ self unableToResumeResponse ]! !

!WADebugErrorHandler methodsFor: 'actions' stamp: 'jf 9/19/2008 19:45'!
handleDefault: anException
	^ self debugAndResume: anException! !

!WADebugErrorHandler methodsFor: 'actions' stamp: 'jf 9/14/2008 13:34'!
open: anException
	SeasidePlatformSupport openDebuggerOn: anException! !

!WADebugErrorHandler methodsFor: 'content' stamp: 'jf 9/14/2008 15:35'!
unableToResumeResponse
	| content |
	content := WARenderCanvas builder
		fullDocument: true;
		rootBlock: [ :root | root title: 'Unable to proceed' ];
		render: [ :html |
			html heading level1; with: 'Unable to proceed - hit Refresh to retry'.
			html paragraph: 'Some exceptions cannot be resumed. You will usually see this page if you hit Proceed while debugging one of these exceptions. Your request was aborted but you can retry it by refreshing the page.' ].
	
	^ WAResponse new
		internalError;
		nextPutAll: content;
		yourself! !

WADebugErrorHandler subclass: #WAWalkbackErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAWalkbackErrorHandler commentStamp: 'jf 10/27/2008 22:44' prior: 0!
I am the default development error handler that displays the stack frames and adds the option to display a debugger.

I delegate the rendering to WAWalkback.

This handler uses Components and depends on having a valid Session. If an error occurs outside of the Session scope it will simply use the superclass behaviour, which should be to open a debugger.!

!WAWalkbackErrorHandler methodsFor: 'private' stamp: 'lr 11/14/2008 23:45'!
open: anException
	| answer |
	self requestContext request isXmlHttpRequest ifTrue: [ ^ super open: anException ].
	
	"If an error occurs outside the scope of a session or the part of the session where
	WACurrentRequestContext is defined, we need to catch this and just use the super
	behaviour."
	[answer := self session isNil or:
				[ self session inNewRenderLoopCall:
					(SeasidePlatformSupport walkbackClass exception: anException) ].
	answer ifTrue: [ super open: anException ] ]
		on: WARequestContextNotFound
		do: [ :err | super open: anException ]! !

!WAPackage class methodsFor: '*seaside-development' stamp: 'lr 10/23/2008 21:13'!
seasideDevelopment
	^ self new
		name: 'Seaside-Development';
		description: 'Web-based development tools and debugging support.';
		addDependency: 'Seaside-Environment';
		yourself! !

WADecoration subclass: #WAToolDecoration
	instanceVariableNames: 'plugins showHalos'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAToolDecoration class methodsFor: 'testing' stamp: 'lr 9/14/2008 12:54'!
canBeRoot
	^ true! !

!WAToolDecoration methodsFor: 'initialization' stamp: 'lr 9/25/2008 11:26'!
initialize
	super initialize.
	showHalos := WAValueHolder with: false! !

!WAToolDecoration methodsFor: 'testing' stamp: 'lr 1/3/2008 13:15'!
isGlobal
	^ true! !

!WAToolDecoration methodsFor: 'accessing' stamp: 'lr 9/13/2008 17:14'!
plugins
	^ plugins ifNil: [ plugins := WAToolPlugin allSubclassesOn: self component for: self ]! !

!WAToolDecoration methodsFor: 'rendering' stamp: 'jf 11/3/2008 22:28'!
renderChildOn: html
	self showHalos
		ifTrue: [ html context debugMode ].
	self renderNextOn: html.
	html context clearMode! !

!WAToolDecoration methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderContentOn: html
	self renderChildOn: html.
	self renderToolbarOn: html! !

!WAToolDecoration methodsFor: 'rendering' stamp: 'lr 9/25/2008 10:40'!
renderToolbarOn: html
	html div id: 'toolbar'; with: [
		(self plugins select: [ :each | each isActive ])
			do: [ :each | html render: each ]
			separatedBy: [ html text: ' ' ] ]! !

!WAToolDecoration methodsFor: 'accessing' stamp: 'lr 6/5/2007 21:46'!
showHalos
	^ showHalos contents! !

!WAToolDecoration methodsFor: 'accessing' stamp: 'lr 4/15/2007 18:46'!
states
	^ Array with: showHalos! !

!WAToolDecoration methodsFor: 'plugin-halos' stamp: 'lr 3/24/2008 11:20'!
toggleHalos
	showHalos contents: showHalos contents not! !

!WAToolDecoration methodsFor: 'updating' stamp: 'MAD 8/29/2008 18:02'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	WADevelopmentFiles default updateRoot: anHtmlRoot! !

!WARequestHandler methodsFor: '*seaside-development' stamp: 'jf 10/7/2008 01:18'!
cloneHandler
	^ self copy! !

!WARequestHandler methodsFor: '*seaside-development' stamp: 'jf 7/21/2008 23:47'!
configurationComponent
	^ WAHandlerEditor on: self! !

WARequestFilter subclass: #WADeprecatedToolFilter
	instanceVariableNames: 'notifications'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Filter'!

!WADeprecatedToolFilter methodsFor: 'actions' stamp: 'lr 9/25/2008 15:13'!
deprecated: aNotification
	notifications add: aNotification.
	aNotification resume! !

!WADeprecatedToolFilter methodsFor: 'initialization' stamp: 'lr 9/25/2008 11:25'!
initialize
	super initialize.
	self reset! !

!WADeprecatedToolFilter methodsFor: 'accessing' stamp: 'lr 9/25/2008 15:13'!
notifications
	^ notifications! !

!WADeprecatedToolFilter methodsFor: 'actions' stamp: 'lr 9/25/2008 15:12'!
reset
	notifications := OrderedCollection new! !

!WADeprecatedToolFilter methodsFor: 'processing' stamp: 'lr 9/25/2008 14:24'!
responseForContext: aRequestContext
	^ [ super responseForContext: aRequestContext ]
		on: WADeprecatedApi
		do: [ :notification | self deprecated: notification ]! !

WARequestFilter subclass: #WATimingToolFilter
	instanceVariableNames: 'startTime previousTiming'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Filter'!

!WATimingToolFilter methodsFor: 'accessing' stamp: 'lr 9/25/2008 15:29'!
currentTiming
	"Answer the running timing, or 0 if no value is available."

	^ startTime isNil ifTrue: [ 0 ] ifFalse: [ Time millisecondsSince: startTime ]! !

!WATimingToolFilter methodsFor: 'accessing' stamp: 'lr 9/25/2008 15:29'!
previousTiming
	"Answer the previous timing, or 0 if no value is available."

	^ previousTiming ifNil: [ 0 ]! !

!WATimingToolFilter methodsFor: 'processing' stamp: 'pmm 11/4/2008 20:17'!
responseForContext: aRequestContext
	startTime := Time millisecondClockValue.
	^ [ super responseForContext: aRequestContext ]
		ensure: [ previousTiming := self currentTiming ]! !

WAComponent subclass: #WAHalo
	instanceVariableNames: 'root mode plugins'
	classVariableNames: 'Halos'
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAHalo class methodsFor: 'instance-creation' stamp: 'lr 5/11/2007 01:05'!
for: aComponent
	^ Halos at: aComponent ifAbsentPut: [ self new initializeOn: aComponent ]! !

!WAHalo class methodsFor: 'class initialization' stamp: 'lr 3/24/2008 11:20'!
initialize
	Halos := SeasidePlatformSupport weakDictionaryOfSize: 20! !

!WAHalo methodsFor: 'rendering' stamp: 'jf 10/21/2008 20:11'!
canHaveHalo
	^ false! !

!WAHalo methodsFor: 'initialization' stamp: 'lr 9/5/2007 11:46'!
initializeOn: aComponent
	root := aComponent.
	mode := WAValueHolder with: self modes first.
	plugins := WAHaloPlugin allSubclassesOn: self root for: self! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 12/6/2006 20:25'!
mode
	^ mode contents! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 12/6/2006 20:24'!
mode: aSymbol
	mode contents: aSymbol! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 3/26/2007 22:26'!
modes
	^ #( render: source: )! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 5/11/2007 01:06'!
plugins
	^ plugins! !

!WAHalo methodsFor: 'rendering-modes' stamp: 'lr 5/11/2007 09:39'!
render: html
	self root renderContentOn: html! !

!WAHalo methodsFor: 'rendering' stamp: 'jf 10/7/2008 19:54'!
renderContentOn: html
	| haloHtml |
	haloHtml := self rendererClass context: html context.
	haloHtml div class: 'halo'; with: [
		haloHtml div class: 'halo-header'; with: [
			(self plugins select: [ :each | each isActive ])
				do: [ :each | html render: each ]
				separatedBy: [ html text: ' ' ] ].
		haloHtml div class: 'halo-body'; with: [
			self perform: self mode with: html ] ].
	haloHtml flush.
	html flush! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 5/11/2007 09:39'!
root
	^ root! !

!WAHalo methodsFor: 'rendering-modes' stamp: 'jf 10/7/2008 21:00'!
source: html
	| context haloHtml |
	haloHtml := self rendererClass context: html context.
	context := haloHtml context copy.
	context clearMode.
	context document: (WAPrettyPrintedDocument renderer: haloHtml).
	haloHtml div
		class: 'halo-source';
		with: [ self root renderWithContext: context ].
	haloHtml flush! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 4/15/2007 18:50'!
states
	^ Array with: mode! !

WAComponent subclass: #WAHandlerEditor
	instanceVariableNames: 'handler'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

WAHandlerEditor subclass: #WADispatcherComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADispatcherComponent methodsFor: 'accessing' stamp: 'lr 2/10/2008 17:19'!
dispatcher: aHandler
	handler := aHandler! !

!WADispatcherComponent methodsFor: 'accessing' stamp: 'lr 10/26/2008 17:07'!
entryPoints
	"Answer a dictionary of the visible entry points."

	^ self handler entryPoints! !

!WADispatcherComponent methodsFor: 'initialization' stamp: 'jf 9/22/2008 21:08'!
initialRequest: aRequest
	"Check my relative URL, if the last entry is an application open the config editor, else open the dispatcher editor."
	
	| requestUrl baseUrl |
	super initialRequest: aRequest.
	requestUrl := aRequest url.
	baseUrl := WAUrl new
		addAllToPath: self application path;
		yourself.
	self openHandler: (self 
		lookupHandler: (baseUrl
			relativeTo: requestUrl))! !

!WADispatcherComponent methodsFor: 'initialization' stamp: 'jf 7/31/2008 15:27'!
initialize
	super initialize.
	self initializeOn: WADispatcher default! !

!WADispatcherComponent methodsFor: 'actions' stamp: 'lr 9/13/2008 16:16'!
lookupHandler: aCollection
	^ aCollection
		inject: self handler
		into: [ :requesthandler :name |
			requesthandler isDispatcher
				ifFalse: [ ^ requesthandler ]
				ifTrue: [
					requesthandler entryPoints 
						at: name
						ifAbsent: [ ^ nil ] ] ]! !

!WADispatcherComponent methodsFor: 'actions' stamp: 'lr 9/13/2008 16:16'!
openHandler: aHandler
	aHandler isNil ifTrue: [ ^ self ].
	self initializeOn: (aHandler isDispatcher
		ifFalse: [ aHandler parent ]
		ifTrue: [ aHandler ])! !

!WADispatcherComponent methodsFor: 'rendering' stamp: 'lr 2/10/2008 16:14'!
renderContentOn: html
	super renderContentOn: html.
	self renderDispatcherOn: html! !

!WADispatcherComponent methodsFor: 'rendering' stamp: 'lr 2/10/2008 17:18'!
renderDispatcherOn: html
	html table: [
		self handler isRoot
			ifFalse: [ self renderRow: self handler parent named: '..' on: html ].
		self entryPoints keysSortedSafely
			do: [ :each | self renderRow: (self handler entryPoints at: each) named: each on: html ] ]! !

!WADispatcherComponent methodsFor: 'rendering-rows' stamp: 'lr 1/5/2007 22:08'!
renderRow: anEntryPoint named: aString on: html
	html tableRow: [
		html tableData: [ self renderRowName: anEntryPoint named: aString on: html ].
		html tableData: [ self renderRowDescription: anEntryPoint named: aString on: html ].
		html tableData: [ self renderRowActions: anEntryPoint named: aString on: html ] ]! !

!WADispatcherComponent methodsFor: 'rendering-rows' stamp: 'lr 1/5/2007 22:08'!
renderRowActions: anEntryPoint named: aString on: html! !

!WADispatcherComponent methodsFor: 'rendering-rows' stamp: 'lr 10/28/2007 14:42'!
renderRowDescription: anEntryPoint named: aString on: html
	aString = self upDirectory
		ifFalse: [ html render: anEntryPoint description ]
		ifTrue: [ html render: 'Parent Directory' ]! !

!WADispatcherComponent methodsFor: 'rendering-rows' stamp: 'lr 2/10/2008 20:09'!
renderRowName: anEntryPoint named: aString on: html
	anEntryPoint isDispatcher
		ifTrue: [ 
			html anchor
				callback: [ self dispatcher: anEntryPoint ];
				with: aString ]
		ifFalse: [
			html anchor 
				url: anEntryPoint basePath , '/'; 
				with: aString ]! !

!WADispatcherComponent methodsFor: 'accessing' stamp: 'lr 4/15/2007 19:54'!
states
	^ Array with: self! !

!WADispatcherComponent methodsFor: 'accessing' stamp: 'lr 2/10/2008 16:19'!
upDirectory
	^ '..'! !

WADispatcherComponent subclass: #WADispatcherEditor
	instanceVariableNames: 'name type'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADispatcherEditor class methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
canBeRoot
	^ true! !

!WADispatcherEditor class methodsFor: 'accessing' stamp: 'lr 2/12/2007 23:16'!
description
	^ 'Dispatcher Editor'! !

!WADispatcherEditor class methodsFor: 'initialization' stamp: 'jf 10/26/2008 17:43'!
initialize
	(WAAdmin register: self asApplicationAt: 'config') addLibrary: WAHandlerEditorFiles! !

!WADispatcherEditor methodsFor: 'actions' stamp: 'lr 10/21/2008 15:41'!
addConfiguration
	(name isNil or: [ name isEmpty ])
		ifTrue: [ self inform: 'You must enter a configuration-name.' ]
		ifFalse: [ self editConfiguration: (self sharedConfiguration named: name) ]! !

!WADispatcherEditor methodsFor: 'actions' stamp: 'jf 10/26/2008 12:24'!
addEntryPoint
	| newHandler editorCommand |
	(name isNil or: [ name isEmpty ])
		ifTrue: [ ^ self inform: 'You must enter a path-name.' ].
	newHandler :=  WAAdmin register: type at: name.
	newHandler isApplication ifTrue: [
		newHandler configuration
			removeParent: WASessionConfiguration instance;
			addParent: WARenderLoopConfiguration instance ].
	editorCommand := WAConfigureDispatcherPlugin on: newHandler for: self.
	editorCommand isActive ifTrue: [ editorCommand execute ]! !

!WADispatcherEditor methodsFor: 'actions' stamp: 'lr 11/28/2008 16:46'!
editConfiguration: aConfiguration
	self show: aConfiguration configurationComponent! !

!WADispatcherEditor methodsFor: 'accessing' stamp: 'lr 2/10/2008 16:13'!
entryPointClasses
	^ WAEntryPoint concreteSubclasses asSortedCollection: [ :a :b | a name < b name ]! !

!WADispatcherEditor methodsFor: 'initialization' stamp: 'lr 2/12/2007 21:01'!
initialize
	super initialize.
	type := WAApplication.
	name := String new! !

!WADispatcherEditor methodsFor: 'actions' stamp: 'lr 11/28/2008 16:43'!
openHandler: aHandler
	super openHandler: aHandler.
	aHandler isApplication
		ifTrue: [ self show: aHandler configurationComponent ]! !

!WADispatcherEditor methodsFor: 'actions' stamp: 'lr 10/21/2008 15:55'!
removeConfiguration: aConfiguration
	aConfiguration unregister! !

!WADispatcherEditor methodsFor: 'rendering-parts' stamp: 'lr 2/10/2008 17:24'!
renderAddEntryPointOn: html
	html heading level: 3; with: 'Add entry point'.
	html form: [
		html table: [
			html tableRow: [
				html tableData class: 'label'; with: 'Name: '.
				html tableData: [
					html textInput
						callback: [ :value | name := value ] ] ].
			html tableRow: [
				html tableData class: 'label'; with: 'Type: '.
				html tableData: [
					html select
						selected: type;
						list: self entryPointClasses;
						callback: [ :value | type := value ];
						labels: [ :each | each description ].
				html space.
				html submitButton
					callback: [ self addEntryPoint ];
					text: 'Add' ] ] ] ]! !

!WADispatcherEditor methodsFor: 'rendering-parts' stamp: 'pmm 10/28/2008 16:30'!
renderConfigurationsOn: html
	html heading level: 2; with: 'Shared Configurations'.
	html form: [
		html unorderedList: [
			self sharedConfiguration configurations do: [ :each |
				html listItem: [
					html anchor
						callback: [ self editConfiguration: each ];
						with: each name.
					html space.
					html anchor
						callback: [ self removeConfiguration: each ];
						with: [ html html: '&times;' ] ] ] ].
		html paragraph: [
			html textInput
				callback: [ :value | name := value ].
			html submitButton
				callback: [ self addConfiguration ];
				text: 'Add' ] ]! !

!WADispatcherEditor methodsFor: 'rendering' stamp: 'lr 11/28/2008 16:46'!
renderContentOn: html
	super renderContentOn: html.
	self renderSettingsOn: html.
	html paragraph: [
		html anchor
			callback: [ self show: self handler configuration configurationComponent ];
			with: 'edit dispatcher configuration' ].
	self renderConfigurationsOn: html! !

!WADispatcherEditor methodsFor: 'rendering-parts' stamp: 'pmm 10/28/2008 16:24'!
renderDefaultEntryPointOn: html
	html heading level: 3; with: 'Default entry point'.
	html form: [
		html paragraph: [
			html select
				beOptional;
				optionalLabel: '(none)';
				list: self handler entryPoints keysSortedSafely;
				on: #defaultName of: self handler.
			html space.
			html submitButton
				text: 'Set' ] ]! !

!WADispatcherEditor methodsFor: 'rendering-rows' stamp: 'jf 8/5/2008 09:03'!
renderRowActions: anEntryPoint named: aString on: html
	aString = self upDirectory ifTrue: [ ^ nil ].
	((WADispatcherPlugin allSubclassesOn: anEntryPoint for: self)
		select: [ :each | each isActive ])
			do: [ :each | html render: each ]
			separatedBy: [ html text: ' ' ]! !

!WADispatcherEditor methodsFor: 'rendering' stamp: 'lr 2/10/2008 17:25'!
renderSettingsOn: html
	html heading level: 2; with: 'Settings'.
	self renderDefaultEntryPointOn: html.
	self renderAddEntryPointOn: html! !

!WADispatcherEditor methodsFor: 'accessing' stamp: 'lr 10/21/2008 15:50'!
sharedConfiguration
	^ WASharedConfiguration! !

WADispatcherComponent subclass: #WADispatcherViewer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADispatcherViewer class methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
canBeRoot
	^ true! !

!WADispatcherViewer class methodsFor: 'accessing' stamp: 'lr 5/9/2007 08:51'!
description
	^ 'Dispatcher Viewer'! !

!WADispatcherViewer class methodsFor: 'initialization' stamp: 'jf 10/26/2008 17:41'!
initialize
	(WAAdmin register: self asApplicationAt: 'browse') addLibrary: WAHandlerEditorFiles.
	WADispatcher default 
		defaultName: 'browse'! !

WAHandlerEditor subclass: #WAEntryPointEditor
	instanceVariableNames: 'configurationEditor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAEntryPointEditor methodsFor: 'accessing' stamp: 'jf 7/21/2008 23:44'!
children
	^ Array with: configurationEditor! !

!WAEntryPointEditor methodsFor: 'initialization' stamp: 'pmm 11/4/2008 20:51'!
initializeOn: aHandler
	super initializeOn: aHandler.
	aHandler configuration isNil ifTrue: [ ^self ].
	
	configurationEditor := aHandler configuration configurationComponent.
	configurationEditor onAnswer: [ self answer ]! !

!WAEntryPointEditor methodsFor: 'rendering' stamp: 'jf 7/21/2008 23:45'!
renderConfigurationOn: html
	handler configuration isNil ifFalse: [
		html render: configurationEditor ]! !

!WAEntryPointEditor methodsFor: 'rendering' stamp: 'jf 7/21/2008 23:46'!
renderContentOn: html
	super renderContentOn: html.
	self renderConfigurationOn: html.! !

!WAEntryPointEditor methodsFor: 'accessing' stamp: 'jf 7/21/2008 23:43'!
title
	^ super title, ' on ' , self handler basePath! !

WAHandlerEditor subclass: #WAFileHandlerEditor
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAFileHandlerEditor methodsFor: 'accessing' stamp: 'jf 8/5/2008 09:26'!
basePath
	^ self handler baseUrl pathString! !

!WAFileHandlerEditor methodsFor: 'actions' stamp: 'lr 11/28/2008 16:45'!
configureLibrary: aLibrary
	self show: aLibrary configurationComponent! !

!WAFileHandlerEditor methodsFor: 'accessing' stamp: 'lr 2/10/2008 18:54'!
libraries
	^ self handler libraries asSortedCollection: [ :a :b | a name < b name ]! !

!WAFileHandlerEditor methodsFor: 'rendering' stamp: 'lr 11/28/2008 16:46'!
renderContentOn: html
	super renderContentOn: html.
	html paragraph: [
		html anchor
			callback: [ self show: self handler configuration configurationComponent ];
			with: 'edit file handler configuration' ].
	html table: [
		self libraries do: [ :each |
			html tableRow: [
				html tableData: each name.
				html tableData: [
					html anchor
						callback: [ self configureLibrary: each default ];
						with: 'configure' ] ] ] ].
	html form: [
		html submitButton
			callback: [ self answer ];
			text: 'close' ]! !

!WAHandlerEditor class methodsFor: 'instance-creation' stamp: 'lr 2/10/2008 14:55'!
on: anEntryPoint
	^ self new initializeOn: anEntryPoint! !

!WAHandlerEditor methodsFor: 'accessing' stamp: 'lr 2/10/2008 15:58'!
handler
	^ handler! !

!WAHandlerEditor methodsFor: 'initialization' stamp: 'lr 2/10/2008 15:58'!
initializeOn: aHandler
	handler := aHandler! !

!WAHandlerEditor methodsFor: 'rendering' stamp: 'lr 2/10/2008 15:37'!
renderContentOn: html
	self renderHeadingOn: html! !

!WAHandlerEditor methodsFor: 'rendering' stamp: 'lr 10/8/2008 09:13'!
renderHeadingOn: html
	html heading class: 'logo'; with: [
		html anchor
			url: (WAUrl new 
				hostname: 'www.seaside.st';
				addParameter: 'version' value: SeasidePlatformSupport versionString;
				addParameter: 'platform' value: SeasidePlatformSupport platformString;
				yourself);
			with: 'Seaside' ].
	html heading class: 'title'; with: [
		html anchor
			url: self handler baseUrl;
			with: self title ]! !

!WAHandlerEditor methodsFor: 'accessing' stamp: 'lr 2/10/2008 17:56'!
title
	^ self handler description! !

!WAHandlerEditor methodsFor: 'processing' stamp: 'jf 7/31/2008 16:11'!
updateRoot: aHtmlRoot
	super updateRoot: aHtmlRoot.
	aHtmlRoot title: self title! !

!WAHandlerEditor methodsFor: 'processing' stamp: 'lr 3/24/2008 14:24'!
updateUrl: anUrl
	| browsePath currentPath |
	super updateUrl: anUrl.
	browsePath := self handler path.
	currentPath := self application path.
	[ browsePath notEmpty and: [ currentPath notEmpty and: [ browsePath first = currentPath first ] ] ] whileTrue: [
		browsePath removeFirst.
		currentPath removeFirst ].
	browsePath do: [ :each | anUrl addToPath: each ]! !

WAComponent subclass: #WAStringLibraryEditor
	instanceVariableNames: 'library'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

WAStringLibraryEditor subclass: #WAFileLibraryEditor
	instanceVariableNames: 'renamingFile newName'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAFileLibraryEditor methodsFor: 'rendering' stamp: 'pmm 8/31/2008 15:21'!
renderAddFileOn: html
	html form multipart; with: [
	 	html div: [
			html text: 'Add File: '.
			html fileUpload on: #addFile of: self library.
			html space.
			html submitButton text: 'Add' ] ]! !

!WAFileLibraryEditor methodsFor: 'rendering' stamp: 'pmm 8/14/2007 07:08'!
renderContentOn: html
	self renderHeadingsOn: html.
	self renderAddFileOn: html.
	self renderFilesOn: html.
	self renderWriteToDiskOn: html.
	self renderDoneOn: html! !

!WAFileLibraryEditor methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderFile: fileName on: html
	html tableData: [
		html anchor
			class: 'download';
			url: (self urlFor: fileName);
			with: fileName ].
	html tableData: [
		html anchor
			callback: [ self library removeFile: fileName ];
			with: 'remove'.
		html space.
		html anchor
			callback: [ renamingFile := fileName ];
			with: 'rename' ]! !

!WAFileLibraryEditor methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderFilesOn: html
	html table: [
		self library filenames asSortedCollection do: [ :each |
			html tableRow: [
				renamingFile = each
					ifTrue: [ self renderRenameFormForFile: each on: html ]
					ifFalse: [ self renderFile: each on: html ] ] ] ]! !

!WAFileLibraryEditor methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderRenameFormForFile: fileName on: html
	html tableData colSpan: 2; with: [
		html form: [
			html textInput
				value: fileName;
				callback: [ :value | newName := value ].
			html submitButton
				callback: [
					self library renameFile: fileName to: newName.
					renamingFile := nil ];
			 	text: 'rename'.
			html cancelButton
				callback: [ renamingFile := nil ];
				text: 'cancel' ] ]! !

!WAFileLibraryEditor methodsFor: 'path' stamp: 'pmm 8/17/2007 07:00'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot title: self library name! !

!WAStringLibraryEditor methodsFor: 'accessing' stamp: 'lr 2/18/2007 12:36'!
library
	^ library! !

!WAStringLibraryEditor methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
library: aLibrary
	library := aLibrary! !

!WAStringLibraryEditor methodsFor: 'rendering' stamp: 'pmm 8/14/2007 07:07'!
renderContentOn: html
	self renderHeadingsOn: html.
	self renderFilesOn: html.
	self renderWriteToDiskOn: html.
	self renderDoneOn: html! !

!WAStringLibraryEditor methodsFor: 'rendering' stamp: 'lr 2/18/2007 12:36'!
renderDoneOn: html
	html form: [
		html submitButton
			callback: [ self answer ];
			text: 'close' ]! !

!WAStringLibraryEditor methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderFilesOn: html
	html unorderedList: [
		self library filenames
			do: [:each |
				html listItem: [
					html anchor
					class: 'download';
						url: (self urlFor: each);
						with: each ] ] ]! !

!WAStringLibraryEditor methodsFor: 'rendering' stamp: 'pmm 8/14/2007 07:12'!
renderHeadingsOn: html
	html heading: self library name! !

!WAStringLibraryEditor methodsFor: 'rendering' stamp: 'pmm 8/14/2007 07:21'!
renderWriteToDiskOn: html
	html form: [
		html submitButton
			callback: [ self library deployFiles ];
			title: 'write all the files to disk';
			text: 'write to disk' ]! !

!WAStringLibraryEditor methodsFor: 'private' stamp: 'pmm 5/23/2007 22:28'!
urlFor: aFilename
	^ self library urlForFile: aFilename! !

WAComponent subclass: #WATool
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WATool commentStamp: 'pmm 10/11/2008 18:58' prior: 0!
A WATool is the common base class for tools called from the development tool bar. Is doesn't do anything but including WADevelopmentFiles.!

WATool subclass: #WADeprecation
	instanceVariableNames: 'table filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADeprecation class methodsFor: 'instance-creation' stamp: 'obi 10/8/2008 20:21'!
on: filter
	^self new filter: filter; yourself! !

!WADeprecation methodsFor: 'private' stamp: 'obi 10/8/2008 20:00'!
buildTable
	^WATableReport new
		rowPeriod: 1;
		rowColors: #( '#eee' 'white' );
		rows: self notifications;
		columns: (Array
			with: (WAReportColumn selector: #messageText title: 'Deprecated')
			with: (WAReportColumn new
						title: 'Detail';
						valueBlock: [:each | each details isNil ifTrue: [''] ifFalse: [each details] ];
						yourself));
		yourself! !

!WADeprecation methodsFor: 'accessing' stamp: 'jf 10/22/2008 22:35'!
children
	^ Array with: table! !

!WADeprecation methodsFor: 'accessing' stamp: 'obi 10/8/2008 20:20'!
filter: aFilter
	filter := aFilter! !

!WADeprecation methodsFor: 'accessing' stamp: 'obi 10/8/2008 20:20'!
notifications
	^filter notifications! !

!WADeprecation methodsFor: 'rendering' stamp: 'pmm 10/11/2008 18:52'!
renderContentOn: html
	html div
		class: 'tool';
		with: [
			html render: self table.
			html anchor
				callback: [ self resetDeprecationWarnings ];
				with: 'Reset deprecation warnings' ]
	! !

!WADeprecation methodsFor: 'actions' stamp: 'pmm 10/11/2008 18:30'!
resetDeprecationWarnings
	filter reset.
	self answer! !

!WADeprecation methodsFor: 'accessing' stamp: 'pmm 10/11/2008 18:31'!
table
	table isNil ifTrue: [
		table := self buildTable ].
	^table! !

WATool subclass: #WAPluggableTool
	instanceVariableNames: 'component'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAPluggableTool commentStamp: 'pmm 11/14/2008 22:28' prior: 0!
A WAPluggableTool is a wrapper component around tools that can't be made subclasses of WATool. WATool is only really needed to provide the icon image.

Instance Variables
	component:		<WAComponent>

component
	- the component to render
!

!WAPluggableTool class methodsFor: 'instance-creation' stamp: 'pmm 11/14/2008 22:25'!
on: aComponent
	^self new
		initializeWith: aComponent;
		yourself! !

!WAPluggableTool methodsFor: 'accessing' stamp: 'pmm 11/14/2008 22:24'!
children
	^Array with: component! !

!WAPluggableTool methodsFor: 'initialization' stamp: 'pmm 11/14/2008 22:25'!
initializeWith: aComponent
	component := aComponent! !

!WATool methodsFor: 'updating' stamp: 'pmm 10/11/2008 18:53'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	WADevelopmentFiles default updateRoot: anHtmlRoot! !

WAComponent subclass: #WAUserConfigurationEditor
	instanceVariableNames: 'configuration'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAUserConfigurationEditor class methodsFor: 'instance-creation' stamp: 'jf 7/21/2008 18:04'!
on: aUserConfiguration
	^ self new initializeOn: aUserConfiguration
	! !

!WAUserConfigurationEditor methodsFor: 'actions' stamp: 'lr 2/12/2007 22:17'!
close
	self answer! !

!WAUserConfigurationEditor methodsFor: 'accessing' stamp: 'jf 7/21/2008 18:05'!
configuration
	^ configuration! !

!WAUserConfigurationEditor methodsFor: 'initialization' stamp: 'lr 8/30/2008 15:50'!
initializeOn: aUserConfiguration
	WASystemConfiguration clearAllDescriptions.
	configuration := aUserConfiguration! !

!WAUserConfigurationEditor methodsFor: 'accessing' stamp: 'lr 8/30/2008 15:25'!
parents
	^ self configuration parents! !

!WAUserConfigurationEditor methodsFor: 'rendering-ancestry' stamp: 'jf 7/31/2008 14:42'!
potentialParents
	^ ((WASystemConfiguration allSubclasses collect: [ :each | each instance ]),
		WASharedConfiguration configurations)
		select: [ :each | 
			(self configuration canAddParent: each)
				and: [ (self configuration inheritsFrom: each) not ] ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-ancestry' stamp: 'lr 8/30/2008 15:25'!
renderAncestryListOn: html 
	self configuration parents isEmpty ifTrue: [ ^ self ].
	html unorderedList: 
		[ self parents do: 
			[ :each | 
			self 
				renderParent: each
				on: html ] ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-ancestry' stamp: 'jf 7/21/2008 18:30'!
renderAncestryOn: html
	html heading level: 2; with: 'Ancestry'.
	self renderParentSelectorOn: html.
	self renderAncestryListOn: html! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'jf 7/18/2008 18:13'!
renderAttribute: anAttribute on: html
	html tableRow: [
		html tableHeading: [
			html label
				title: anAttribute comment;
				with: anAttribute label ].
		html tableData: [
			(self configuration valueForAttribute: anAttribute)
				ifNil: [ self renderUnspecifiedAttribute: anAttribute on: html ]
				ifNotNil: [
					(self configuration hasLocalValueForAttribute: anAttribute)
						ifTrue: [ self renderOverridenAttribute: anAttribute on: html ]
						ifFalse: [ self renderInheritedAttribute: anAttribute on: html ] ] ].
		self renderInheritanceForAttribute: anAttribute on: html ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'jf 7/18/2008 18:09'!
renderAttributesOn: html
	html heading level: 2; with: 'Configuration'.
	html table: [
		self configuration groupedAttributes do: [ :association |
			html tableRow: [
				html tableData
					colSpan: 3;
					with: [ html heading level3; with: (self labelForSelector: association key) ] ].
				association value do: [ :attribute |
				self renderAttribute: attribute on: html ] ] ]! !

!WAUserConfigurationEditor methodsFor: 'rendering' stamp: 'pmm 11/14/2008 21:33'!
renderButtonsOn: html
	html paragraph: [
		html break.
		html submitButton on: #save of: self.
		html submitButton on: #close of: self ]! !

!WAUserConfigurationEditor methodsFor: 'rendering' stamp: 'lr 10/21/2008 15:49'!
renderContentOn: html
	self configuration isShared
		ifTrue: [ html heading: self configuration name ].
	html form: [
		self renderFormOn: html.
		self renderButtonsOn: html ]! !

!WAUserConfigurationEditor methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderFormButtonsOn: html
	html submitButton on: #save of: self.
	html submitButton on: #done of: self! !

!WAUserConfigurationEditor methodsFor: 'rendering' stamp: 'lr 2/12/2007 22:25'!
renderFormOn: html
	self renderAncestryOn: html.
	self renderAttributesOn: html! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'pmm 11/14/2008 21:31'!
renderInheritanceForAttribute: anAttribute on: html
	html tableData: [
		| wasInherited |
		wasInherited := false.
		self configuration inheritedValueAndSourceAt: anAttribute key do: [ :value :source |
			wasInherited ifFalse: [
				(self configuration hasLocalValueForAttribute: anAttribute)
					ifTrue: [
						html anchor 
							title: 'revert to ' , value printString , ', overriden from ', source name;
							callback: [ self configuration clearValueForAttribute: anAttribute ]; 
							with: 'revert' ]
					ifFalse: [
						html anchor 
							title: 'inherited from ', source name;
							callback: [ self configuration overrideAttribute: anAttribute ]; 
							with: 'override'.
						(anAttribute isKindOf: WACollectionAttribute) ifTrue: [
							html text: ' '.
							html anchor
								callback: [ self configuration at: anAttribute key addAll: #() removeAll: #() ];
								with: 'modify' ] ].
			wasInherited := true. ] ].
				
		wasInherited ifFalse: [
			(self configuration hasLocalValueForAttribute: anAttribute)
				ifTrue: [
					html anchor 
						callback: [ self configuration clearValueForAttribute: anAttribute ];
						with: 'clear' ]
				ifFalse: [
					anAttribute default isNil
						ifTrue: [
							html span
								class: 'unspecified';
								with: '(unspecified)' ]
						ifFalse: [
							html anchor 
								title: 'inherited from attribute default';
								callback: [ self configuration overrideAttribute: anAttribute ]; 
								with: 'override'.
							(anAttribute isKindOf: WACollectionAttribute) ifTrue: [
								html text: ' '.
								html anchor
									callback: [ self configuration at: anAttribute key addAll: #() removeAll: #() ];
									with: 'modify' ] ] ] ] ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'lr 2/10/2008 18:10'!
renderInheritedAttribute: anAttribute on: html 
	html text: (self configuration valueForAttribute: anAttribute) printString! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'jf 7/21/2008 14:51'!
renderInheritedValueForAttribute: anAttribute on: html 
	| inheritedValue |
	inheritedValue := self configuration inheritedValueAt: anAttribute key.
	inheritedValue isNil 
		ifTrue: 
			[ html span
				class: 'unspecified';
				with: '(unspecified)' ]
		ifFalse: [ html text: inheritedValue printString ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'lr 2/10/2008 18:17'!
renderOverrideForAttribute: anAttribute on: html 
	html anchor
		callback: [ self configuration overrideAttribute: anAttribute ];
		with: 'edit'! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'avi 3/23/2004 12:34'!
renderOverridenAttribute: anAttribute on: html
	anAttribute accept: self with: html! !

!WAUserConfigurationEditor methodsFor: 'rendering-ancestry' stamp: 'lr 11/28/2008 16:48'!
renderParent: aConfiguration on: html 
	html listItem: [
		aConfiguration isShared
			ifTrue: [ 
				html anchor
					callback: [ self show: aConfiguration configurationComponent ];
					with: aConfiguration name ]
			ifFalse: [ html text: aConfiguration name ].
		html space.
		html anchor
			callback: [ self configuration moveParentUp: aConfiguration ];
			with: [ html html: '&uarr;' ].
		html space.
		html anchor
			callback: [ self configuration moveParentDown:aConfiguration ];
			with: [ html html: '&darr;' ].
		html space.
		html anchor
			callback: [ self configuration removeParent: aConfiguration ];
			with: [ html html: '&times;' ] ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-ancestry' stamp: 'pmm 11/14/2008 21:23'!
renderParentSelectorOn: html 
	| selectedParent parents |
	parents := self potentialParents.
	parents isEmpty ifTrue: [ ^self ].
	
	html paragraph: [
		html text: 'Add Parent: '.
		selectedParent := WAValueHolder new.
		html select
			selected: nil;
			list: parents;
			labels: [ :each | each name ];
			callback: [ :value | selectedParent contents: value ].
		html space.
		html submitButton
			callback: [ self configuration addParent: selectedParent contents ];
			text: 'Add' ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'lr 2/10/2008 18:17'!
renderRevertForAttribute: anAttribute on: html 
	html anchor
		callback: [ self configuration clearValueForAttribute: anAttribute ];
		with: 'clear'! !

!WAUserConfigurationEditor methodsFor: 'rendering-attributes' stamp: 'avi 3/23/2004 12:35'!
renderUnspecifiedAttribute: anAttribute on: html
	anAttribute accept: self with: html! !

!WAUserConfigurationEditor methodsFor: 'actions' stamp: 'avi 3/23/2004 14:36'!
save! !

!WAUserConfigurationEditor methodsFor: 'rendering-visitors' stamp: 'lr 2/10/2008 18:17'!
visitBooleanAttribute: anAttribute with: html 
	html select
		list: (Array with: true with: false);
		selected: (self configuration valueForAttribute: anAttribute);
		callback: [ :value | self configuration takeValue: value forAttribute: anAttribute];
		labels: [ :bool | bool ifTrue: [ 'true' ] ifFalse: [ 'false' ] ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-visitors' stamp: 'a 9/5/2008 20:25'!
visitCollectionAttribute: anAttribute with: html
	| expression |
	expression := self configuration 
		expressionAt: anAttribute key
		ifAbsent: [ ^ self ].
	(expression isKindOf: WAValueExpression)
		ifTrue: [ 
			html multiSelect
				list: anAttribute options;
				on: #value of: expression ]
		ifFalse: [
			html multiSelect
				title: 'removals';
				list: anAttribute options;
				on: #removals of: expression.
			html multiSelect
				title: 'additions';
				list: anAttribute options;
				on: #additions of: expression ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-visitors' stamp: 'lr 2/10/2008 18:18'!
visitListAttribute: anAttribute with: html 
	html select
		beOptional;
		optionalLabel: '(none)';
		list: anAttribute options asArray;
		selected: (self configuration valueForAttribute: anAttribute);
		callback: [ :value | self configuration takeValue: value forAttribute: anAttribute ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-visitors' stamp: 'jf 7/31/2008 16:43'!
visitNumberAttribute: anAttribute with: html 
	html textInput
		size: 5;
		callback: [ :value | self configuration takeValueFromString: value forAttribute: anAttribute ];
		value: (self configuration valueForAttribute: anAttribute)! !

!WAUserConfigurationEditor methodsFor: 'rendering-visitors' stamp: 'jf 7/19/2008 20:44'!
visitPasswordAttribute: anAttribute with: html 
	html passwordInput 
		callback: [ :value | self configuration takeValueFromString: value forAttribute: anAttribute ]! !

!WAUserConfigurationEditor methodsFor: 'rendering-visitors' stamp: 'jf 7/19/2008 20:44'!
visitStringAttribute: anAttribute with: html 
	html textInput
		callback: [ :value | self configuration takeValueFromString: value forAttribute: anAttribute ];
		value: (self configuration valueForAttribute: anAttribute)! !

WASystemConfiguration subclass: #WADevelopmentConfiguration
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADevelopmentConfiguration methodsFor: 'description' stamp: 'jf 9/17/2008 20:13'!
describeOn: config
	config at: #rootDecorationClasses addAll: (Array with: WAToolDecoration).
	config at: #libraries addAll: (Array with: WADevelopmentFiles).
	config at: #exceptionHandler put: WAWalkbackErrorHandler! !

!WADevelopmentConfiguration methodsFor: 'description' stamp: 'lr 9/14/2008 13:39'!
parents
	^ Array with: WARenderLoopConfiguration instance with: WAApplicationConfiguration instance! !

!WAApplication methodsFor: '*seaside-development' stamp: 'jf 10/27/2008 11:24'!
cloneHandler
	^ super cloneHandler
		clear;
		yourself! !

!WAConfiguration methodsFor: '*seaside-development' stamp: 'pmm 11/4/2008 20:22'!
addAncestorsTo: linearCollection forAttributeAt: aSymbol 
	| found result attribute |
	found := false.
	attribute := nil.
	(linearCollection includes: self) 
		ifTrue: [ ^ true ]
		ifFalse: [
			linearCollection add: self.
			aSymbol notNil and: [ self canDefineAttributes and: [ self attributes at: aSymbol ifPresent: [ :attr | ^ attr ] ] ].
			self parents isEmpty ifFalse: [
				self parents reverseDo: [ :each | 
					result := each
						addAncestorsTo: linearCollection
						forAttributeAt: aSymbol.
					result isNil ifFalse: [
						found := true.
						result == true ifFalse: [ attribute := result ] ] ] ] ].
	found ifFalse: [ linearCollection removeLast ].
	^ (found and: [ attribute isNil ]) ifTrue: [ true ] ifFalse: [ attribute ]! !

!WAConfiguration methodsFor: '*seaside-development' stamp: 'jf 7/23/2008 12:54'!
ancestryLinearizedForAttributeAt: aSymbol
	| linear |
	linear := OrderedCollection new.
	self addAncestorsTo: linear forAttributeAt: aSymbol.
	^ linear asArray! !

!WAConfiguration methodsFor: '*seaside-development' stamp: 'jf 8/4/2008 16:12'!
findValuesAndSourcesAt: aSymbol inAll: linear do: aBlock
	linear do:
		[ :each |
		each expressionAt: aSymbol ifPresent:
			[ :expression | 
			aBlock value: expression value: each ] ]! !

!WAConfiguration methodsFor: '*seaside-development' stamp: 'jf 7/29/2008 18:39'!
groupedAttributes
	| grops attributes |
	grops := Dictionary new.
	attributes := SortedCollection sortBlock: [ :a :b | a key <= b key].
	self allAttributes valuesDo: [ :each |
		(grops at: each group ifAbsentPut: [ SortedCollection sortBlock: [:a :b | a key <= b key ] ] )
			add: each ].
	grops associationsDo: [ :associaction |
		attributes add: associaction ].
	^ attributes! !

!WAConfiguration methodsFor: '*seaside-development' stamp: 'jf 8/4/2008 16:13'!
hasLocalValueForAttribute: anAttribute
	self expressionAt: anAttribute key ifAbsent: [^ false].
	^ true! !

!WAConfiguration methodsFor: '*seaside-development' stamp: 'jf 7/24/2008 19:20'!
inheritedValueAndSourceAt: aSymbol do: aBlock 
	| ancestors |
	ancestors := (self ancestryLinearizedForAttributeAt: aSymbol) allButFirst.
	self 
		findValuesAndSourcesAt: aSymbol
		inAll: ancestors
		do: 
			[ :value :source | 
			^ aBlock 
				value: value
				value: source ]! !

!WAConfiguration methodsFor: '*seaside-development' stamp: 'jf 8/4/2008 15:50'!
inheritedValueAt: aSymbol 
	| context |
	context := WAAttributeContext key: aSymbol target: self.

	context attribute isNil ifTrue: [ ^ nil ].
	
	^ self inheritedValueAt: aSymbol context: aSymbol! !

!WAConfiguration methodsFor: '*seaside-development' stamp: 'jf 10/5/2008 14:52'!
valueForAttribute: anAttribute
	^ self at: anAttribute key! !

WALabelledFormDialog subclass: #WAViewer
	instanceVariableNames: 'presenter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAViewer class methodsFor: 'instance-creation' stamp: 'avi 3/13/2004 01:13'!
on: aPresenter
	^ self new presenter: aPresenter! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:14'!
buttons
	^ #(save)! !

!WAViewer methodsFor: 'actions' stamp: 'pmm 7/28/2007 10:27'!
compile: aString
	SeasidePlatformSupport
		compile: aString
		into: presenter class
		classified: #rendering! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:14'!
model
	^ presenter! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:13'!
presenter: aPresenter
	presenter := aPresenter! !

!WAViewer methodsFor: 'rendering' stamp: 'lr 8/30/2008 16:22'!
renderContentOn: html 
	html heading
		level3;
		with: presenter seasideString.
	super renderContentOn: html! !

!WAViewer methodsFor: 'rendering' stamp: 'pmm 7/28/2007 10:27'!
renderCssOn: html
	html textArea
		rows: 20;
		columns: 80;
		value: presenter style;
		callback: [ :css | self compile: 'style ^ ', css printString]! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:14'!
rows
	^ #(css)! !

!WAViewer methodsFor: 'actions' stamp: 'lr 10/28/2007 14:42'!
save! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:22'!
script
	^ 'self.opener.location=self.opener.location'! !

!WAEntryPoint methodsFor: '*seaside-development' stamp: 'jf 7/21/2008 23:46'!
configurationComponent
	^ WAEntryPointEditor on: self! !

WAHtmlDocument subclass: #WAPrettyPrintedDocument
	instanceVariableNames: 'html indentLevel indentCloseTags firstLine'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAPrettyPrintedDocument class methodsFor: 'instance-creation' stamp: 'avi 5/22/2004 12:40'!
renderer: aRenderer
	^ self basicNew initializeWithRenderer: aRenderer! !

!WAPrettyPrintedDocument methodsFor: 'writing-xhtml' stamp: 'pmm 8/31/2008 14:46'!
attribute: aKey with: aValue 
	aValue == false ifTrue: [ ^ self ].
	html space.
	html span
		class: (self cssClassForAttribute: aKey);
		with: aKey.
	html text: '='.
	html span
		class: 'attribute-value';
		with: [
			html text: '"'.
			(self knownRefs includes: aKey) 
				ifTrue: [
					html anchor
						url: aValue seasideString;
						with: aValue ]
				ifFalse: [
					(self knownEvents includes: aKey) 
						ifTrue: [
							html anchor
								onClick: aValue;
								with: aValue ]
						ifFalse: [
							aValue == true 
								ifTrue: [ html text: aKey ]
								ifFalse: [ html render: aValue ] ] ].
			html text: '"' ]! !

!WAPrettyPrintedDocument methodsFor: 'writing-xhtml' stamp: 'lr 4/20/2007 22:11'!
attributes: anAttributes
	anAttributes ifNil: [ ^ self ].
	anAttributes keysAndValuesDo: [ :key :value | self attribute: key with: value ]! !

!WAPrettyPrintedDocument methodsFor: 'writing-xhtml' stamp: 'lr 10/28/2007 14:42'!
closeTag: aString
	indentLevel := indentLevel - 1.
	indentCloseTags removeLast
		ifTrue: [ self indent ].
	html text: '</'.
	html span class: (self cssClassFor: aString); with: aString.
	html text: '>'! !

!WAPrettyPrintedDocument methodsFor: 'private' stamp: 'lr 4/20/2007 22:13'!
cssClassFor: aString
	^ (self knownTags includes: aString)
		ifTrue: [ 'tag-known' ]
		ifFalse: [ 'tag-unknown' ]! !

!WAPrettyPrintedDocument methodsFor: 'private' stamp: 'lr 4/20/2007 22:13'!
cssClassForAttribute: aString
	^ (self knownAttributes includes: aString)
		ifTrue: [ 'attribute-known' ]
		ifFalse: [ 'attribute-unknown' ]! !

!WAPrettyPrintedDocument methodsFor: 'accessing' stamp: 'lr 3/26/2007 22:28'!
document
	^ html document! !

!WAPrettyPrintedDocument methodsFor: 'accessing' stamp: 'lr 5/11/2007 11:39'!
htmlEncoder
	^ self document htmlEncoder! !

!WAPrettyPrintedDocument methodsFor: 'private' stamp: 'lr 4/20/2007 22:29'!
indent
	firstLine
		ifTrue: [ firstLine := false ]
		ifFalse: [ html break ].
	indentLevel timesRepeat: [ html space: 2 ]! !

!WAPrettyPrintedDocument methodsFor: 'initialization' stamp: 'lr 11/23/2006 10:02'!
initializeWithRenderer: aRenderer
	html := aRenderer.
	indentCloseTags := OrderedCollection with: false.
	indentLevel := 0.
	firstLine := true! !

!WAPrettyPrintedDocument methodsFor: 'configuration' stamp: 'lr 4/20/2007 22:05'!
knownAttributes
	^ #('abbr' 'accept' 'accept' 'accesskey' 'action' 'align' 'alink' 'alt' 'archive' 'axis' 'background' 'bgcolor' 'bgproperties' 'border' 'cellpadding' 'cellspacing' 'char' 'charoff' 'charset' 'charset' 'checked' 'cite' 'class' 'classid' 'clear' 'code' 'codebase' 'codetype' 'color' 'cols' 'colspan' 'compact' 'content' 'coords' 'data' 'datetime' 'declare' 'defer' 'dir' 'direction' 'disabled' 'encoding' 'enctype' 'equiv' 'face' 'for' 'frame' 'frameborder' 'framespacing' 'gutter' 'headers' 'height' 'href' 'hreflang' 'hspace' 'http' 'id' 'ismap' 'label' 'lang' 'leftmargin' 'link' 'longdesc' 'loop' 'lowsrc' 'marginheight' 'marginwidth' 'maxlength' 'media' 'method' 'methods' 'multiple' 'name' 'nohref' 'noresize' 'noshade' 'nowrap' 'object' 'onabort' 'onblur' 'onchange' 'onclick' 'ondblclick' 'onerror' 'onfocus' 'onkeydown' 'onkeypress' 'onkeyup' 'onload' 'onmousedown' 'onmousemove' 'onmouseout' 'onmouseover' 'onmouseup' 'onreset' 'onselect' 'onsubmit' 'onunload' 'prompt' 'readonly' 'rel' 'rev' 'rows' 'rowspan' 'rules' 'scheme' 'scope' 'scrolling' 'selected' 'shape' 'size' 'span' 'src' 'standby' 'style' 'summary' 'tabindex' 'target' 'text' 'title' 'type' 'urn' 'usemap' 'valign' 'value' 'valuetype' 'version' 'vlink' 'vspace' 'width' 'wrap' 'xml:lang' 'xmlns')! !

!WAPrettyPrintedDocument methodsFor: 'configuration' stamp: 'lr 5/11/2007 11:13'!
knownEvents
	^ #('onabort' 'onblur' 'onchange' 'onclick' 'ondblclick' 'onerror' 'onfocus' 'onkeydown' 'onkeypress' 'onkeyup' 'onload' 'onmousedown' 'onmousemove' 'onmouseout' 'onmouseover' 'onmouseup' 'onreset' 'onselect' 'onsubmit' 'onunload')! !

!WAPrettyPrintedDocument methodsFor: 'configuration' stamp: 'lr 4/20/2007 22:11'!
knownRefs
	^ #('action' 'cite' 'classid' 'codebase' 'data' 'href' 'longdesc' 'profile' 'src' 'usemap')! !

!WAPrettyPrintedDocument methodsFor: 'configuration' stamp: 'lr 4/20/2007 21:14'!
knownTags
	^ #('a' 'abbr' 'acronym' 'address' 'area' 'b' 'base' 'bdo' 'big' 'blockquote' 'body' 'br' 'button' 'caption' 'cite' 'code' 'col' 'colgroup' 'dd' 'del' 'dfn' 'div' 'dl' 'dt' 'em' 'fieldset' 'form' 'h1' 'h2' 'h3' 'h4' 'h5' 'h6' 'head' 'hr' 'html' 'i' 'img' 'input' 'ins' 'ismap' 'kbd' 'label' 'legend' 'li' 'link' 'map' 'meta' 'noscript' 'object' 'ol' 'optgroup' 'option' 'p' 'param' 'pre' 'q' 'rb' 'rbc' 'rp' 'rt' 'rtc' 'ruby' 'samp' 'script' 'select' 'small' 'span' 'strong' 'style' 'sub' 'sup' 'table' 'tbody' 'td' 'textarea' 'tfoot' 'th' 'thead' 'title' 'tr' 'tt' 'ul' 'var')! !

!WAPrettyPrintedDocument methodsFor: 'writing' stamp: 'lr 5/11/2007 11:39'!
nextPut: aCharacter
	self htmlEncoder nextPut: aCharacter! !

!WAPrettyPrintedDocument methodsFor: 'writing' stamp: 'lr 5/11/2007 11:39'!
nextPutAll: aString
	self htmlEncoder nextPutAll: aString! !

!WAPrettyPrintedDocument methodsFor: 'writing-xhtml' stamp: 'lr 10/28/2007 14:42'!
openTag: aString attributes: anAttributes closed: aBoolean
	self indent.
	html text: '<'.
	html span
		class: (self cssClassFor: aString);
		with: aString.
	self attributes: anAttributes.
	aBoolean
		ifTrue: [ html text: '/' ].
	html text: '>'.
	aBoolean
		ifFalse: [ indentLevel := indentLevel + 1 ].
	indentCloseTags removeLast; addLast: true; addLast: aBoolean! !

!WAPrettyPrintedDocument methodsFor: 'writing' stamp: 'lr 5/11/2007 11:40'!
print: anObject
	self document print: anObject! !

WAFileLibrary subclass: #WADevelopmentFiles
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADevelopmentFiles commentStamp: 'jf 10/6/2008 21:27' prior: 0!
CSS and images used by the web-based development tools.

The icons are from the Tango Desktop Project (tango.freedesktop.org), they are licensed under the Creative Commons Attribution Share-Alike license.
!

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 18:58'!
codebrowserPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 9 22 18 55 41 59 82 2 72 0 0 1 203 73 68 65 84 56 203 165 147 77 104 19 65 20 199 127 51 221 163 72 22 34 45 226 177 224 41 160 88 43 1 15 130 21 132 120 236 69 208 182 39 175 165 23 21 60 138 32 197 32 245 34 126 128 154 22 138 49 189 91 26 17 77 92 16 237 193 98 211 141 27 76 253 192 213 108 235 16 21 90 145 205 120 48 67 179 109 106 43 190 203 255 13 204 251 207 111 102 222 131 255 12 97 146 226 93 250 128 25 224 216 86 122 120 136 188 169 147 0 151 71 47 157 1 102 14 30 119 216 142 182 18 88 77 189 1 240 237 249 57 182 163 87 79 74 221 172 59 45 141 211 222 84 64 89 21 88 221 147 167 172 10 252 232 122 216 86 95 76 75 6 199 138 28 233 31 6 24 55 4 196 227 113 196 137 165 63 139 125 77 101 77 125 223 39 127 79 50 116 237 25 31 158 140 51 183 16 132 64 135 213 122 31 165 20 245 122 125 195 75 7 65 128 155 73 173 21 123 203 124 45 77 117 0 61 17 3 219 182 177 109 59 82 236 251 62 110 38 197 224 88 145 197 199 25 94 149 151 81 165 28 64 207 200 100 99 246 175 4 230 228 129 116 129 197 124 134 185 183 10 85 202 241 115 255 69 206 159 189 48 11 136 77 9 180 214 20 210 189 12 92 121 138 55 125 135 202 231 239 168 249 7 188 239 26 166 179 205 55 70 8 180 214 100 179 89 126 201 67 204 59 14 239 62 213 89 122 61 5 189 105 118 173 172 0 218 52 161 110 75 16 134 33 187 63 166 121 244 165 155 251 185 28 221 242 37 59 251 110 145 76 38 113 93 151 55 149 5 140 139 92 79 80 173 86 241 60 143 145 201 6 71 59 43 172 238 72 16 30 24 37 145 72 96 89 22 150 101 69 186 120 3 65 44 22 67 107 77 173 86 67 107 141 148 18 173 53 66 8 132 16 173 219 27 17 3 165 20 142 227 108 58 117 198 100 125 24 131 137 155 183 175 159 250 135 41 158 48 201 111 90 157 232 152 121 9 252 18 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 19:44'!
configPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 11 4 11 55 32 209 169 238 103 0 0 0 29 116 69 88 116 67 111 109 109 101 110 116 0 67 114 101 97 116 101 100 32 119 105 116 104 32 84 104 101 32 71 73 77 80 239 100 37 110 0 0 1 217 73 68 65 84 56 203 197 147 77 107 19 97 20 133 159 105 107 131 52 157 52 35 161 38 67 55 129 198 221 132 100 66 72 138 88 117 37 53 89 137 8 21 4 33 100 254 65 17 92 117 33 136 43 17 55 45 253 3 165 45 8 67 178 81 12 88 65 145 188 249 152 162 130 219 36 148 137 52 37 89 180 136 31 113 97 103 72 219 116 213 133 119 117 121 207 229 112 239 57 231 133 115 150 116 22 240 244 217 147 190 211 63 90 122 124 230 220 152 211 220 189 119 39 163 235 113 19 64 136 74 22 32 159 51 88 93 91 57 134 157 36 115 9 116 61 110 230 115 6 150 101 1 152 161 160 74 203 110 16 10 170 160 99 166 146 105 52 77 3 232 15 146 140 13 178 89 150 197 165 105 63 183 179 11 238 91 44 17 37 70 212 197 79 214 168 211 248 21 191 248 211 255 189 24 185 50 75 171 209 98 251 221 118 175 109 183 61 59 214 78 111 202 55 229 153 240 78 80 42 149 16 162 146 253 242 249 235 183 99 27 56 130 133 130 42 0 181 90 173 103 219 223 95 9 81 221 84 20 229 170 36 141 62 92 200 220 10 56 231 232 122 220 213 98 196 97 202 231 12 98 137 127 171 250 124 62 185 217 108 110 110 172 111 153 157 78 231 189 44 123 3 206 57 249 156 49 220 133 213 181 21 66 65 149 88 34 202 193 193 225 225 220 92 122 9 32 28 14 27 221 110 183 7 200 213 114 157 194 110 241 180 6 111 94 191 93 246 43 126 49 57 233 93 188 113 237 38 63 127 253 184 208 110 183 3 145 200 236 3 73 226 242 252 245 121 121 220 51 78 69 84 16 162 146 125 241 252 229 253 161 54 166 146 105 90 118 3 117 70 69 157 81 47 30 65 178 51 147 74 166 1 204 141 245 45 215 198 145 193 117 52 77 99 207 222 167 96 22 169 150 235 0 84 203 117 10 102 145 61 123 223 201 193 112 13 142 84 237 187 73 212 49 51 211 25 10 187 69 39 153 230 199 79 31 78 37 241 220 127 225 255 215 95 179 89 175 43 2 12 187 45 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-styles' stamp: 'pmm 11/14/2008 22:17'!
haloCss
	^ '.halo {
	margin: 2px;
	border: 1px solid #aaa;
}

/* header */
.halo-header {
	overflow: hidden;
	padding: 2px;
	color: #444;
	background-color: #eee;
	border-bottom: 1px solid #aaa;
	font: 10pt Verdana, Arial, Helvetica, sans-serif;
}
.halo-header a {
	text-decoration: none;
}
.halo-header div {
	float: left;
}
.halo-header div.classnamehaloplugin,
.halo-header div.browserhaloplugin,
.halo-header div.inspectorplugin,
.halo-header div.styleshaloplugin {
	float: left;
	display: block;
	padding-right: 5px;
}
.halo-header div.browserhaloplugin, div.window-titlebar div.browserhaloplugin {
	background: url(codebrowser.png) no-repeat;
}
.halo-header div.inspectorplugin, div.window-titlebar div.inspectorplugin {
	background: url(inspector.png) no-repeat;
}
.halo-header div.styleshaloplugin, div.window-titlebar div.styleshaloplugin {
	background: url(styleeditor.png) no-repeat;
}
.halo-header div.browserhaloplugin a,
.halo-header div.inspectorplugin a,
.halo-header div.styleshaloplugin a {
	width: 16px;
	display: block;
	text-indent: -32000px;
	background-position: 0 50%;
	outline: none;
}
.halo-header div.modehaloplugin {
	float: right;
	display: block;
}
.halo-header div.modehaloplugin a {
	color: #444;
}
.halo-header div.modehaloplugin a:hover {
	color: #111;
}
.halo-header div.modehaloplugin a.active {
	font-weight: bold;
}
div.window-titlebar div.profilertoolplugin {
	background: url(profiler.png) no-repeat;
}
div.window-titlebar div.memorytoolplugin {
	background: url(memory.png) no-repeat;
}
div.window-titlebar div.configuretoolplugin {
	background: url(config.png) no-repeat;
}

/* body */
.halo-body {
	clear: both;
	padding: 2px;
}

/* source */
.halo-source .tag-known {
	font-weight: bold;
	color: navy;
}
.halo-source .attribute-known {
	color: navy;
}
.halo-source .attribute-value {
	color: purple;
}
.halo-source .comment {
	font-style: italic;
	color: green;
}'! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 18:58'!
inspectorPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 240 0 240 0 239 52 6 103 27 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 11 5 16 15 5 37 253 173 47 0 0 1 246 73 68 65 84 56 203 157 146 77 107 19 81 24 133 159 59 201 36 77 154 102 134 74 82 10 10 181 93 104 26 69 20 193 133 184 20 10 85 119 226 38 191 192 111 169 244 31 136 182 36 65 68 20 116 89 119 85 16 197 77 168 59 65 236 162 84 40 164 137 86 171 150 80 53 141 205 71 39 77 50 51 215 69 72 73 66 82 170 103 119 15 239 61 239 225 188 71 60 121 250 120 49 247 39 119 140 61 64 85 213 231 19 183 38 47 182 144 211 209 187 150 220 35 238 77 223 145 237 162 78 41 235 92 62 191 185 235 118 77 211 59 242 78 33 196 206 35 153 76 118 28 10 133 66 93 133 119 28 180 15 102 50 25 102 95 204 2 144 152 75 0 208 180 107 119 7 223 190 175 146 74 167 57 122 106 140 109 197 139 105 43 184 100 133 212 252 107 38 110 223 140 196 162 247 159 53 254 40 237 14 52 93 35 149 78 115 232 228 24 159 11 94 6 7 2 140 28 8 82 18 62 180 209 113 252 154 62 115 237 198 149 227 93 29 36 230 18 12 135 79 179 82 112 115 233 204 16 190 30 21 211 182 81 29 10 239 150 37 193 35 227 54 75 111 22 0 1 160 116 10 75 122 3 12 13 232 88 182 100 219 52 169 212 44 202 85 139 126 159 155 95 101 181 37 9 69 74 137 148 118 75 48 110 183 11 132 160 92 181 168 214 36 155 91 53 220 170 131 253 253 30 164 16 45 93 112 2 182 105 154 45 78 108 99 131 53 163 138 223 163 162 247 185 176 45 137 223 227 228 211 70 129 125 61 150 157 107 114 174 212 43 234 66 211 116 52 77 231 194 185 243 164 23 222 18 236 19 124 249 153 39 155 43 145 55 42 124 92 89 167 84 174 144 91 122 229 44 21 139 63 26 2 34 26 159 154 177 44 43 210 124 13 195 48 112 56 84 78 156 141 176 188 86 100 203 84 24 236 149 172 47 190 100 248 224 8 0 31 230 223 167 30 62 120 116 88 116 107 216 213 235 151 167 2 129 224 100 51 231 235 245 17 30 13 243 59 155 173 247 101 245 43 130 127 68 44 30 149 13 145 255 18 0 148 88 60 106 1 148 13 131 191 6 140 246 211 127 51 231 46 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 19:44'!
memoryPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 10 19 17 58 52 159 194 36 103 0 0 1 240 73 68 65 84 56 203 165 147 61 104 20 65 24 134 159 221 153 157 221 189 194 20 34 18 209 75 97 12 66 208 72 2 1 33 96 97 115 96 17 36 106 180 17 82 88 137 193 70 17 15 46 133 164 176 178 49 130 149 86 134 147 72 136 88 156 66 42 27 65 68 61 73 180 9 130 7 241 206 52 10 130 119 59 127 22 49 49 33 39 74 124 225 101 186 103 158 225 251 38 40 149 138 15 128 115 108 35 222 251 105 74 165 162 111 181 154 190 217 106 250 191 197 57 231 51 157 173 183 84 42 122 185 70 155 184 59 79 185 82 253 167 155 71 11 135 185 112 162 7 0 9 16 69 138 114 165 138 234 0 37 99 136 20 103 142 46 67 16 50 251 166 11 156 7 60 24 139 54 134 114 165 202 248 233 62 0 194 141 100 21 167 68 105 202 217 161 58 23 135 7 17 74 146 38 9 105 46 69 37 41 34 151 144 36 9 0 214 152 223 6 107 17 42 70 36 49 253 61 123 8 115 5 250 187 27 168 232 19 143 23 14 32 188 3 35 201 66 13 128 177 118 171 65 148 40 70 6 107 236 219 213 193 203 165 6 93 249 83 136 72 146 36 49 81 162 16 113 132 138 213 159 13 78 14 212 8 3 137 200 21 224 219 44 65 48 130 144 130 171 199 159 179 80 223 141 179 14 235 44 83 111 3 140 109 3 184 60 122 157 128 128 143 181 25 222 47 127 37 191 23 14 229 119 114 164 211 48 216 55 142 247 0 158 169 251 183 218 3 110 207 220 68 40 129 148 17 66 10 62 55 230 232 221 63 202 195 215 53 204 247 59 88 99 177 198 254 122 130 221 10 120 242 174 155 40 85 168 88 17 197 10 33 63 112 176 243 25 190 89 35 12 2 158 46 245 210 252 145 1 139 237 13 96 117 222 22 71 232 29 206 57 46 61 234 192 249 29 104 109 208 86 99 113 171 6 27 1 90 103 140 13 15 112 111 238 213 38 220 226 60 192 139 182 155 184 242 101 101 179 193 149 243 67 92 27 59 134 214 25 89 43 67 27 141 214 107 231 134 26 77 163 81 95 135 73 96 122 114 242 198 246 127 227 255 230 39 112 67 0 83 217 168 244 129 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 18:59'!
profilerPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 4 115 66 73 84 8 8 8 8 124 8 100 136 0 0 0 9 112 72 89 115 0 0 4 157 0 0 4 157 1 124 52 107 161 0 0 0 25 116 69 88 116 83 111 102 116 119 97 114 101 0 119 119 119 46 105 110 107 115 99 97 112 101 46 111 114 103 155 238 60 26 0 0 3 25 73 68 65 84 56 141 101 147 79 104 219 117 24 198 63 223 111 218 181 105 27 243 167 165 127 213 181 22 35 181 171 237 198 152 204 22 230 193 169 200 14 67 24 84 152 135 194 16 188 8 66 17 113 243 44 115 189 120 16 65 135 5 157 90 240 160 224 230 182 67 41 108 172 44 235 97 3 219 117 90 211 218 37 105 154 52 77 211 52 77 242 203 239 251 199 131 53 108 250 192 115 123 223 207 203 3 239 35 172 181 60 170 177 209 113 25 104 14 156 10 132 90 94 110 244 53 29 208 74 233 236 230 230 189 108 58 115 253 171 111 63 185 202 127 36 30 5 188 59 246 241 96 248 64 223 55 62 191 127 64 169 138 168 171 3 173 20 219 185 50 78 197 213 249 173 252 157 244 218 218 91 95 127 255 233 234 255 0 227 239 157 127 59 220 223 247 89 93 67 77 176 183 219 71 103 48 129 150 65 124 161 126 42 21 205 159 75 113 230 34 247 217 217 113 210 235 177 216 169 139 151 206 223 168 2 206 156 254 176 249 224 139 135 127 243 135 188 29 195 71 2 120 202 119 168 245 182 83 44 149 8 118 190 134 244 120 81 74 145 201 100 185 118 121 150 100 114 251 143 116 34 49 48 57 53 81 145 0 79 247 118 127 39 106 100 199 161 161 30 230 102 127 165 232 212 163 157 36 30 247 47 246 213 122 144 82 34 165 36 24 244 51 114 236 32 96 194 77 1 255 231 0 114 108 116 92 120 27 26 15 181 181 122 233 122 178 131 55 222 252 128 153 217 24 209 165 251 56 187 15 1 133 16 226 159 188 66 208 209 217 194 11 131 61 212 213 213 31 5 144 66 136 103 129 64 40 244 4 198 24 16 130 177 119 206 177 190 219 207 236 92 148 197 197 69 172 181 143 185 185 37 136 54 170 125 108 116 188 94 122 106 106 142 26 107 106 125 190 122 86 86 163 104 173 81 74 113 226 228 25 86 182 70 184 114 245 38 174 235 98 173 197 24 67 98 45 134 223 223 132 209 38 4 246 57 169 149 138 56 101 199 221 201 151 120 170 107 127 21 176 177 177 129 197 195 240 240 8 214 90 180 214 24 99 104 111 235 36 159 47 0 228 64 44 73 107 237 239 21 167 146 201 110 230 80 74 85 125 225 194 4 199 143 191 194 208 208 32 90 235 170 141 49 100 82 89 132 144 201 201 169 137 162 156 156 154 176 197 194 238 194 194 252 67 50 153 44 74 41 92 215 229 236 217 143 8 135 195 184 174 91 133 106 173 201 109 21 184 125 123 30 167 84 140 0 72 128 92 38 115 122 183 224 108 220 186 113 143 157 157 66 117 120 59 159 163 92 46 85 33 197 221 50 215 126 185 9 200 196 149 235 63 156 171 2 38 167 38 74 15 22 238 126 17 141 166 203 63 253 56 67 34 190 177 119 85 163 181 65 107 67 124 53 205 165 201 203 36 83 185 98 36 50 125 49 182 22 13 10 33 164 176 214 34 132 104 4 122 7 250 142 188 62 252 210 171 239 123 27 26 219 189 245 251 232 238 105 163 226 104 150 151 227 184 174 182 249 252 86 106 122 230 231 47 227 201 149 8 240 0 88 174 118 65 8 225 7 158 169 173 217 183 255 240 208 177 147 173 173 157 207 55 183 180 117 25 173 77 42 21 95 79 165 18 75 119 231 111 77 91 107 215 128 5 32 102 173 181 143 181 113 239 227 26 129 16 224 7 124 123 49 139 64 1 200 0 219 214 90 243 239 206 223 67 200 195 25 126 17 209 190 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing' stamp: 'pmm 10/11/2008 18:44'!
selectorsToInclude
	^#(
		toolbarCss
		haloCss
		toolsCss
	)! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 18:59'!
styleeditorPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 214 4 9 20 4 42 36 195 187 166 0 0 2 112 73 68 65 84 56 203 173 147 221 75 83 113 24 199 63 155 155 110 57 245 164 169 232 24 180 240 173 50 207 48 74 144 68 27 82 209 141 43 147 145 136 226 159 97 36 236 70 130 174 162 232 38 34 42 86 104 26 42 5 74 47 243 5 65 212 110 52 148 48 95 74 156 107 206 236 156 249 50 117 110 167 139 58 232 130 186 144 30 248 193 247 226 249 124 248 61 207 143 31 28 172 146 107 156 213 74 119 119 183 114 16 216 180 15 222 19 184 65 116 67 167 27 228 223 167 211 13 226 31 112 226 126 184 198 89 173 104 84 24 232 183 55 54 10 73 201 41 16 217 37 184 178 66 95 107 171 4 84 44 222 110 89 150 229 96 219 204 204 76 89 93 109 61 85 85 85 212 56 171 105 111 123 169 87 5 157 246 250 122 135 226 245 18 24 25 1 69 225 136 77 132 212 52 94 127 15 140 249 46 86 230 100 103 153 15 23 228 159 160 188 188 92 133 117 64 36 14 224 42 60 40 42 41 73 88 236 233 97 119 99 131 104 56 204 178 94 199 156 205 198 194 217 211 230 230 155 46 163 86 27 135 40 138 108 132 130 60 122 248 88 7 68 0 180 234 112 74 40 4 202 222 78 190 230 230 225 63 83 76 83 83 51 62 159 143 188 188 60 218 59 94 176 24 76 222 108 56 89 89 168 246 169 2 79 48 16 32 45 63 31 157 193 192 252 229 75 248 47 216 185 238 172 197 231 243 97 52 26 233 31 232 227 211 236 23 4 177 250 208 146 144 237 138 17 76 31 79 126 254 166 191 87 193 100 226 104 105 41 19 69 133 92 113 92 99 109 109 13 69 81 88 95 15 50 60 58 202 80 192 138 201 168 195 159 146 105 143 17 124 168 73 170 141 27 44 211 188 21 38 232 26 241 144 62 61 133 167 239 61 130 32 32 203 50 119 238 221 229 227 143 12 66 187 113 108 135 35 49 239 170 3 208 155 37 123 162 152 195 192 173 49 182 36 3 130 55 132 102 106 146 150 251 207 8 71 34 172 104 173 44 109 9 164 101 89 9 200 219 100 202 126 79 140 0 32 204 38 74 244 87 150 204 195 196 235 102 241 246 26 176 228 22 99 200 182 112 42 43 129 213 245 29 62 15 116 72 54 105 201 21 35 8 123 5 207 106 116 206 97 201 201 96 97 122 25 128 236 226 45 178 114 94 49 120 99 202 247 77 41 72 4 200 148 253 30 155 180 228 122 50 249 110 92 21 104 0 28 117 86 49 122 46 208 127 190 193 34 24 73 37 202 46 235 138 159 161 167 43 146 118 40 189 162 203 61 63 254 183 143 161 81 131 163 206 42 238 28 219 113 233 205 146 93 189 85 252 92 188 235 95 240 127 169 159 24 23 11 103 188 240 115 88 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-styles' stamp: 'lr 9/25/2008 17:53'!
toolbarCss
	^ 'body {
	margin-bottom: 25px;
}
#toolbar {
	z-index: 20;
	position: fixed;
	left: 0;
	right: 0;
	bottom: 0;
	padding: 2px;
	color: #444;
	background-color: #eee;
	border-top: 1px solid #aaa;
	font: 10pt Verdana, Arial, Helvetica, sans-serif;
}
#toolbar a {
	color: #444;
	padding-left: 3px;
	padding-right: 3px;
	text-decoration: none;
}
#toolbar a:hover {
	color: #111;
}
#toolbar a.deprecationtoolplugin {
	color: #ff7000;
}'! !

!WADevelopmentFiles methodsFor: 'accessing-styles' stamp: 'pmm 10/11/2008 19:01'!
toolsCss
	^ '
.tool strong {
	color: #444444;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 12px;
	margin: 2px
}

.tool a, .tool a:link, .tool a:active, .tool a:visited, .tool a:focus, .tool a:hover {
	color:#008AFF;
	font-family: Helvetica, Verdana, Arial, sans-serif;
	font-size: 12px;
}

.tool table {
	border-collapse:collapse;
}

.tool table td {
	font: 10pt Verdana, Arial, Helvetica, sans-serif;
	padding-left: 5px;
	padding-right: 5px;
}
	
.tool .right {
	text-align: right;
}'! !

!WAFileLibrary methodsFor: '*seaside-development' stamp: 'pmm 4/22/2006 00:41'!
configurationComponent
	^ WAFileLibraryEditor new
		library: self;
		yourself! !

WAFileLibrary subclass: #WAHandlerEditorFiles
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAHandlerEditorFiles methodsFor: 'accessing-pictures' stamp: 'lr 5/22/2007 21:52'!
faviconIco
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(0 0 1 0 1 0 16 16 0 0 1 0 32 0 104 4 0 0 22 0 0 0 40 0 0 0 16 0 0 0 32 0 0 0 1 0 32 0 0 0 0 0 0 4 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 252 252 252 253 247 247 247 253 254 254 254 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 103 117 237 253 42 51 220 253 229 230 239 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 72 116 250 253 0 51 246 253 73 95 225 253 247 247 247 253 255 255 255 253 255 255 255 253 255 255 255 253 253 253 253 253 249 249 249 253 254 254 254 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 83 137 252 253 0 87 254 253 0 88 252 253 126 146 226 253 251 251 251 253 242 242 247 253 164 164 233 253 70 70 222 253 30 30 216 253 226 226 237 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 95 152 252 253 0 126 255 253 0 111 255 253 3 103 251 253 63 97 231 253 17 55 231 253 0 45 236 253 0 11 226 253 32 33 220 253 242 242 245 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 252 252 252 253 79 145 249 253 0 158 255 253 0 98 255 253 0 149 255 253 0 149 254 253 0 106 250 253 0 33 233 253 2 31 232 253 185 185 233 253 254 254 254 253 255 255 255 253 255 255 255 253 254 254 254 253 232 237 245 253 148 184 243 253 58 136 245 253 0 136 254 253 0 163 255 253 0 113 255 253 0 134 255 253 0 118 255 253 0 84 250 253 0 92 250 253 107 113 225 253 253 253 253 253 255 255 255 253 255 255 255 253 254 254 254 253 107 164 246 253 7 108 252 253 0 118 255 253 0 135 255 253 0 134 255 253 0 128 255 253 0 104 255 253 0 82 255 253 0 110 255 253 0 146 255 253 4 77 240 253 231 231 237 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 80 153 251 253 1 113 254 253 0 129 255 253 0 143 255 253 0 147 255 253 0 144 255 253 0 116 255 253 0 89 255 253 0 96 255 253 0 144 255 253 0 114 250 253 143 149 220 253 253 253 253 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 227 238 251 253 158 199 250 253 88 171 251 253 9 149 254 253 0 167 255 253 0 121 255 253 0 143 255 253 0 136 255 253 0 89 255 253 0 104 253 253 7 60 235 253 187 187 226 253 254 254 254 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 138 184 251 253 0 155 255 253 0 109 255 253 0 162 255 253 0 143 255 253 0 133 255 253 0 88 251 253 0 30 233 253 25 31 219 253 223 223 236 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 161 197 252 253 0 137 255 253 0 115 255 253 4 140 253 253 154 182 242 253 163 188 251 253 89 130 247 253 19 37 230 253 0 0 222 253 151 151 227 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 169 201 252 253 0 109 255 253 0 117 255 253 113 161 240 253 253 253 253 253 255 255 255 253 254 254 254 253 250 250 252 253 212 212 245 253 249 249 251 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 177 205 252 253 0 94 255 253 38 115 246 253 241 243 247 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 227 236 253 253 61 127 250 253 197 213 243 253 254 254 254 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 254 254 254 253 254 254 254 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 255 255 255 253 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0) asByteArray ].
	^ cache at: 1! !

!WAHandlerEditorFiles methodsFor: 'accessing-pictures' stamp: 'lr 10/6/2008 21:54'!
logoPng
	"The official logo was designed by Samuel Morello. He released it under the Creative Commons Attribution-No Derivative Works 3.0 license (http://creativecommons.org/licenses/by-nd/3.0/)."

	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 200 0 0 0 106 8 3 0 0 0 206 82 238 73 0 0 0 25 116 69 88 116 83 111 102 116 119 97 114 101 0 65 100 111 98 101 32 73 109 97 103 101 82 101 97 100 121 113 201 101 60 0 0 3 0 80 76 84 69 8 150 238 164 187 200 8 93 145 227 227 227 243 47 0 5 149 237 252 68 0 165 205 229 1 88 140 0 142 229 133 195 233 231 22 0 119 186 227 17 99 149 72 132 169 222 222 222 116 178 216 1 83 133 230 230 230 132 167 188 211 211 211 59 165 230 0 137 220 199 217 229 12 96 147 179 181 178 1 86 137 208 208 208 225 229 225 183 200 211 196 143 140 107 185 233 233 233 232 255 155 0 104 152 180 149 200 230 233 236 232 0 146 236 43 150 217 67 172 236 219 219 219 218 218 218 215 215 215 152 180 196 233 225 216 134 170 192 255 92 0 247 250 246 46 163 235 16 154 238 13 153 238 0 143 230 216 216 216 124 163 188 212 212 212 255 163 0 223 4 1 185 213 231 243 247 242 255 100 0 81 135 168 58 118 155 201 178 166 239 243 238 255 146 0 50 120 161 192 76 72 255 114 0 0 140 226 213 221 225 238 162 105 196 205 211 222 224 221 247 251 246 83 166 216 232 235 231 0 144 232 179 137 133 255 107 0 206 44 43 13 141 219 201 157 154 255 81 0 239 175 131 231 215 203 255 130 0 255 138 0 92 180 234 237 238 236 117 158 182 255 122 0 13 146 228 218 220 217 202 93 90 235 201 174 246 146 78 245 249 244 211 218 221 239 242 238 236 112 52 234 136 99 203 212 219 204 207 203 241 245 240 41 113 156 235 239 234 172 195 208 44 157 226 155 194 218 205 210 213 160 198 221 240 242 240 231 234 230 154 190 212 0 145 234 255 172 0 2 147 237 38 109 152 237 241 236 234 236 234 248 252 247 101 145 172 213 216 212 19 155 238 211 214 210 230 127 70 171 208 231 195 201 204 74 173 234 229 232 228 189 115 112 168 192 206 249 119 25 194 197 193 199 210 217 238 240 238 230 233 229 228 231 228 233 71 47 213 30 28 130 185 219 29 147 218 223 227 223 0 146 235 179 162 158 231 231 231 223 56 27 34 159 236 30 155 231 246 248 245 16 148 229 243 246 243 243 245 242 74 170 228 179 193 202 206 209 205 220 223 221 0 135 217 162 200 224 30 105 148 0 138 223 172 200 217 244 247 244 227 230 226 220 223 219 250 92 11 236 237 235 216 225 231 96 148 178 238 240 237 125 191 232 248 140 56 246 249 246 213 213 212 198 190 184 7 146 231 31 107 152 215 218 214 22 156 238 6 144 227 217 217 217 190 206 217 166 194 210 89 173 225 71 124 157 214 214 214 10 143 225 28 99 140 19 153 236 15 151 233 209 209 209 20 152 232 134 192 227 91 144 175 217 218 217 30 103 146 3 147 234 3 145 231 87 140 172 15 91 137 194 107 94 9 148 232 250 77 1 229 229 229 228 228 228 246 250 245 224 224 224 244 248 243 242 246 241 238 242 237 236 240 235 225 225 225 234 238 233 3 91 143 228 232 227 230 234 229 242 244 241 21 102 151 209 211 208 70 160 215 16 96 145 15 90 135 199 202 198 228 229 227 78 176 237 246 174 117 221 221 221 201 204 200 224 225 224 237 191 173 14 143 222 27 143 215 229 229 228 141 175 195 245 238 228 215 207 198 57 157 218 222 141 137 178 207 225 226 228 225 64 128 166 233 237 233 210 69 61 14 139 216 29 151 226 249 94 26 213 213 213 252 87 0 112 150 173 209 156 125 250 103 10 240 193 151 64 169 234 249 253 248 250 254 249 251 255 250 199 109 83 34 0 0 22 165 73 68 65 84 120 218 212 155 13 92 148 117 182 199 193 145 55 33 7 198 65 82 33 68 134 28 134 156 44 94 68 70 26 92 32 157 134 200 40 94 101 219 81 215 69 44 19 137 134 217 44 149 181 104 88 19 226 166 105 105 102 96 166 172 107 173 75 181 83 98 89 109 183 152 153 103 128 1 95 202 205 189 179 222 238 122 175 43 146 93 168 187 206 112 207 57 255 103 94 120 177 165 20 149 127 31 243 51 204 248 225 255 125 206 57 191 243 59 255 231 25 175 254 49 181 28 180 134 123 199 107 108 113 232 204 26 141 89 103 31 235 32 14 221 127 63 240 192 109 218 54 179 125 140 131 216 45 191 144 247 189 254 63 146 18 149 99 108 131 232 148 114 185 188 111 217 19 61 109 58 199 152 6 81 149 202 145 228 251 157 29 22 251 152 6 49 75 20 10 185 66 241 250 193 70 165 217 49 150 65 52 199 21 217 10 121 145 98 217 23 106 62 185 28 14 187 78 167 179 131 34 143 37 16 135 230 33 69 122 186 60 55 79 254 253 158 82 139 29 33 204 150 18 109 169 50 197 108 119 140 41 16 203 67 138 162 92 121 122 84 238 235 7 195 181 22 179 38 165 253 193 127 124 147 188 233 31 234 18 179 125 172 129 228 165 41 20 81 81 233 203 118 132 75 122 30 250 229 111 3 147 113 237 232 76 209 141 41 144 148 135 20 105 81 233 242 180 57 81 242 101 191 124 170 213 215 215 119 60 145 60 115 76 169 26 75 32 246 148 135 178 211 162 114 229 185 115 230 164 101 43 178 211 139 138 250 198 35 199 55 95 53 142 37 16 135 93 165 124 32 59 106 78 154 60 125 206 156 57 81 81 105 105 185 138 241 129 129 129 201 155 158 127 242 88 201 88 73 45 160 48 91 218 31 124 186 8 16 160 72 8 36 183 207 119 188 175 111 96 242 189 127 219 211 105 25 11 197 238 112 232 84 154 146 142 7 31 248 69 122 81 212 99 115 230 164 247 165 33 71 122 171 111 78 118 246 248 228 223 60 243 7 189 82 53 6 228 23 172 123 201 109 255 188 251 233 244 162 188 168 199 30 3 144 220 190 162 40 168 20 223 214 244 188 220 190 228 159 29 124 178 81 171 177 95 239 134 168 58 177 77 229 184 252 180 68 28 150 127 254 46 29 41 230 60 70 107 78 90 159 34 55 61 167 85 158 7 81 9 188 111 202 142 218 82 139 238 58 119 246 237 245 70 88 75 129 194 110 183 95 6 197 97 254 143 108 16 168 220 188 180 180 40 170 141 168 220 190 156 156 214 156 116 120 153 231 187 233 249 95 237 97 94 248 58 130 28 152 110 164 101 170 68 14 251 101 194 98 79 249 93 54 91 10 182 228 242 156 156 156 190 92 32 138 202 14 188 23 10 132 77 39 215 15 196 49 93 36 18 133 69 71 27 77 166 19 78 142 97 96 236 13 119 3 4 228 86 110 110 81 81 122 58 224 200 49 32 185 16 144 180 214 64 72 44 45 155 23 175 31 200 9 145 232 141 200 59 189 188 34 77 2 17 25 216 225 151 221 162 190 251 105 133 34 27 138 132 45 144 221 156 62 36 73 203 147 7 62 63 13 122 161 227 186 130 96 64 242 239 184 211 203 167 34 83 192 53 152 117 158 155 87 53 28 112 131 104 148 141 79 222 245 212 255 41 20 233 80 239 184 242 114 20 121 69 57 168 89 80 235 95 133 183 95 95 16 199 237 144 87 107 9 196 143 227 150 154 117 206 236 218 186 186 82 4 133 35 218 187 141 48 192 169 167 104 143 47 124 226 171 239 159 146 203 179 243 16 36 61 7 10 36 55 199 183 47 61 187 53 249 179 143 122 44 215 46 181 96 119 219 7 168 44 252 189 93 36 138 70 144 138 24 63 161 240 89 179 157 150 106 53 22 142 72 68 26 80 223 64 34 0 36 202 14 117 248 158 39 15 126 255 58 248 69 48 140 242 52 204 176 190 241 227 251 228 227 147 239 170 109 167 34 185 6 32 7 10 104 95 251 111 31 144 251 171 69 162 9 107 239 128 128 148 239 18 10 181 4 162 90 42 98 43 108 221 92 248 7 38 227 86 157 10 34 165 83 169 44 37 237 157 250 218 39 238 234 3 191 152 219 138 202 11 218 219 26 24 232 235 155 188 105 199 113 146 173 209 7 217 198 139 172 201 120 187 167 54 17 8 100 86 76 214 46 155 80 171 130 129 117 27 69 35 108 194 134 59 32 80 135 34 51 77 130 74 179 217 140 40 8 163 41 209 30 47 94 86 4 86 139 41 86 90 94 81 107 114 50 216 248 159 23 195 52 114 13 26 98 3 82 172 107 138 54 153 4 5 131 65 48 179 202 227 31 149 218 16 228 4 98 248 253 117 237 90 72 56 0 244 153 45 176 114 75 53 26 141 138 170 199 14 78 69 217 184 44 61 42 45 71 158 151 150 167 104 237 83 100 103 183 6 38 195 60 114 63 40 240 232 131 216 235 69 162 185 179 189 188 96 95 2 129 71 114 217 25 8 100 86 192 163 82 136 136 106 53 70 227 175 135 0 3 57 32 229 98 130 56 225 233 54 11 145 80 113 57 52 61 255 155 30 149 142 114 149 51 30 13 252 120 54 87 109 218 161 110 211 141 58 200 106 163 40 236 16 106 83 76 52 103 61 225 194 56 208 64 32 152 89 8 178 84 213 0 28 115 95 240 228 40 127 81 104 19 150 148 88 240 172 215 78 42 97 238 4 136 190 156 92 224 248 108 202 243 63 223 4 16 52 32 222 2 245 62 234 238 23 220 212 6 226 40 15 226 184 103 73 154 116 171 247 214 139 234 33 82 19 32 179 234 226 9 196 92 96 36 14 134 65 159 207 10 56 47 149 74 148 64 162 98 237 178 223 220 227 171 72 247 149 195 92 248 217 148 191 125 241 197 87 183 124 67 19 123 242 189 123 58 52 163 13 162 50 26 195 232 2 215 149 127 200 113 171 145 99 181 200 185 38 80 137 32 136 18 20 65 116 137 194 225 245 66 100 62 112 212 101 197 7 4 39 52 215 104 75 218 0 68 231 4 145 247 249 202 115 198 127 51 101 71 113 120 99 248 158 39 14 254 230 62 72 173 187 106 71 31 4 74 125 29 11 200 139 75 56 235 1 187 189 129 53 138 185 235 16 132 50 11 64 184 213 16 144 104 198 145 15 2 215 4 159 143 15 200 8 150 201 186 59 218 75 44 102 39 136 218 55 7 15 28 254 13 44 239 113 173 178 189 244 120 119 241 142 131 247 63 243 135 99 202 209 78 45 7 70 132 15 136 144 3 75 181 13 41 214 229 99 49 228 135 53 65 55 68 16 27 183 122 58 6 4 57 102 131 78 155 194 136 99 247 57 131 193 86 170 45 73 209 240 86 76 115 28 40 160 204 239 253 170 248 184 210 12 138 220 6 221 37 188 54 92 175 133 129 100 84 65 224 151 67 141 68 2 72 11 112 112 39 116 58 136 199 27 249 135 88 77 31 130 20 194 13 63 42 228 86 27 141 111 220 129 28 94 77 192 97 18 64 129 100 236 222 125 78 220 43 237 209 42 221 32 255 137 24 129 159 81 8 236 56 2 155 161 83 106 181 74 139 106 84 229 151 244 105 59 117 145 166 48 142 227 42 161 87 24 69 111 92 26 32 77 1 8 98 85 194 135 232 103 62 235 0 67 96 165 128 76 62 39 22 51 16 190 218 205 183 161 232 254 108 202 147 225 56 219 178 51 9 157 10 123 230 168 117 118 143 126 81 73 109 93 96 181 10 10 84 170 122 145 177 137 149 2 73 83 5 92 121 2 1 19 51 129 126 234 227 135 28 28 5 4 65 138 123 74 25 8 146 152 247 254 54 57 249 190 41 95 176 217 214 253 203 70 235 52 126 192 52 97 63 128 14 112 110 244 92 129 192 212 128 77 197 213 184 15 87 80 73 187 64 238 188 147 172 48 96 248 5 81 64 38 223 35 22 219 122 58 148 109 78 16 85 201 131 247 223 242 204 147 181 61 109 215 226 142 21 57 241 130 202 202 202 165 219 200 188 62 11 229 62 19 46 62 120 148 130 189 70 81 36 187 240 179 195 76 166 13 49 117 8 18 0 32 48 244 230 179 100 107 10 122 169 37 11 241 0 228 57 113 82 173 39 136 93 211 174 175 13 63 86 58 28 199 85 7 113 108 45 168 231 125 184 177 30 70 216 3 240 119 40 4 160 98 182 201 52 93 100 20 205 70 142 138 152 48 48 44 97 117 229 30 32 51 239 100 50 93 158 149 21 207 64 54 47 16 247 30 147 116 184 83 203 174 179 40 161 180 83 84 163 127 87 215 177 117 58 223 236 152 229 125 86 7 217 20 77 151 186 2 236 47 228 24 227 8 229 184 51 86 193 236 114 172 17 23 8 147 105 164 0 14 16 223 136 164 164 102 53 43 118 222 110 57 92 165 61 58 32 174 137 201 193 186 246 220 9 249 27 102 206 140 12 131 141 99 167 139 244 0 137 198 235 14 118 69 40 172 225 4 27 234 202 49 139 220 32 172 104 112 133 6 191 38 51 24 12 225 146 206 246 146 20 179 19 132 253 170 225 55 225 117 245 10 27 20 10 40 222 136 158 189 150 137 171 207 4 216 121 37 121 45 23 72 19 230 79 93 86 144 77 168 231 4 77 172 72 118 49 16 146 99 4 11 13 218 101 147 74 99 19 100 178 132 154 158 210 118 165 39 200 229 151 215 149 82 168 26 26 26 236 60 7 236 213 239 133 181 60 71 69 69 197 186 33 32 145 94 24 16 24 65 132 101 2 0 137 193 144 120 128 212 101 189 251 200 114 169 77 40 20 218 128 36 33 65 218 89 170 28 117 16 254 160 128 170 97 250 118 224 216 15 61 57 18 187 29 219 120 76 76 204 108 147 177 158 146 6 95 154 144 100 38 93 246 0 2 65 75 133 33 241 0 41 207 218 133 24 28 183 235 165 248 128 135 151 39 52 171 75 149 37 163 11 2 133 199 31 20 56 79 10 182 193 78 131 14 29 230 57 64 126 202 203 235 194 48 10 44 105 98 4 78 144 58 0 177 9 213 38 0 65 183 30 143 32 38 103 68 96 128 183 114 214 104 212 179 140 231 192 253 142 46 8 230 209 9 94 158 150 175 92 185 18 39 242 250 233 2 171 223 161 195 135 91 192 136 55 69 182 192 6 227 179 202 253 24 136 15 250 114 1 146 204 244 33 144 93 66 110 47 128 248 12 6 137 41 135 119 172 2 193 150 58 114 191 9 9 221 165 84 236 186 171 12 226 174 107 38 179 203 103 205 59 121 211 77 55 223 60 110 198 18 52 22 220 11 135 14 183 180 120 229 11 76 130 15 73 125 178 206 187 210 169 174 220 234 6 129 189 115 5 38 99 147 235 133 27 196 15 57 194 98 24 136 108 32 72 255 85 0 25 116 142 185 29 155 222 202 121 39 79 50 142 174 174 163 128 193 69 127 240 193 225 22 175 67 153 192 36 132 86 16 16 176 133 227 35 130 153 198 49 144 10 218 59 39 64 16 47 39 72 189 19 36 198 15 56 76 126 56 31 102 100 60 34 147 213 116 92 77 144 33 199 152 91 1 35 243 40 97 32 199 184 46 127 255 151 65 104 222 253 224 3 8 200 37 8 142 208 246 109 70 70 198 226 243 156 105 250 96 16 74 39 4 49 14 0 49 81 2 86 196 76 128 150 47 152 64 1 217 93 109 144 169 175 98 68 134 28 99 58 110 135 120 188 125 129 199 96 28 254 133 82 169 244 225 23 91 90 62 255 252 5 228 176 61 247 237 195 249 111 11 173 158 32 86 23 72 185 159 192 84 234 4 193 202 23 1 136 15 129 68 34 72 40 155 171 146 122 155 37 165 56 33 178 19 161 43 3 113 171 19 121 142 233 13 232 3 33 30 143 243 24 200 1 32 83 63 141 141 141 125 241 197 197 159 127 238 243 73 190 21 250 0 112 217 132 156 64 235 2 201 114 131 196 120 128 176 153 29 181 216 135 222 106 201 180 114 239 102 145 215 90 35 78 90 40 41 85 182 17 136 227 138 64 208 221 172 118 169 83 4 146 136 14 128 49 23 137 46 48 140 125 113 27 231 19 199 212 84 104 95 139 23 47 254 252 205 79 202 203 183 124 40 180 65 80 128 99 169 197 19 68 64 215 29 59 140 159 201 84 73 163 35 76 86 25 143 198 74 171 172 168 197 21 168 9 91 94 218 18 64 211 200 151 98 177 184 74 226 97 126 127 26 8 95 13 13 78 117 194 125 159 44 204 52 26 247 234 246 27 69 103 89 82 157 5 178 106 30 68 38 147 109 126 111 241 155 127 6 144 242 44 64 129 182 102 221 111 241 4 225 4 174 4 2 16 124 195 7 79 131 50 30 73 136 85 115 2 63 4 100 118 24 49 38 223 186 224 136 120 167 190 199 195 252 254 72 144 129 234 132 24 222 164 78 148 69 243 33 59 240 198 223 5 74 170 11 212 10 177 66 166 134 164 130 197 187 231 189 63 254 17 64 234 208 138 111 137 198 141 87 166 12 11 130 195 9 252 211 195 56 234 102 236 126 68 150 160 135 232 181 48 195 146 65 24 175 220 186 96 218 17 67 149 122 196 109 100 16 200 96 149 197 104 56 69 150 170 33 145 114 162 154 94 141 75 52 82 68 48 32 33 169 73 189 189 207 33 200 159 17 164 60 171 188 60 244 60 108 188 146 7 1 159 43 244 0 161 35 134 104 52 187 88 11 6 89 85 183 144 11 34 83 207 48 94 249 114 193 180 105 226 218 50 126 172 210 217 29 63 10 196 115 184 195 117 0 213 105 133 39 135 255 77 2 147 209 100 220 56 14 87 215 70 188 172 137 60 136 56 169 247 247 239 186 64 200 160 76 128 235 238 4 201 138 23 98 181 95 98 169 181 1 65 102 163 105 135 109 175 73 50 52 234 133 194 204 135 89 141 3 198 185 53 211 144 67 47 233 24 113 64 60 65 6 15 119 168 78 200 225 194 192 36 138 64 167 145 72 32 39 145 227 108 151 19 68 156 36 54 4 3 72 86 29 145 212 213 213 197 76 96 166 17 107 58 43 30 139 223 20 201 138 189 238 188 32 236 18 249 41 216 247 26 177 33 188 7 106 106 73 208 183 16 143 69 231 130 35 0 227 200 239 129 3 19 11 166 170 31 7 50 100 184 99 234 196 56 86 20 238 99 28 254 133 152 234 17 93 200 129 42 118 150 137 111 8 130 244 138 13 205 111 135 34 8 146 192 159 152 24 102 26 125 104 96 2 57 182 10 80 155 98 104 158 197 129 150 93 127 152 104 245 18 61 73 118 130 172 87 44 62 2 24 226 61 85 192 1 211 161 197 21 144 17 130 240 195 221 219 179 142 78 156 56 177 176 26 135 187 253 34 81 28 227 216 7 53 157 72 69 61 181 16 220 169 192 116 246 194 133 68 80 176 204 125 227 60 64 154 63 234 77 144 218 194 242 63 129 88 240 201 213 68 94 139 156 123 128 84 10 33 137 198 112 208 92 8 85 125 142 149 195 52 113 66 153 164 83 98 37 16 67 18 168 110 111 113 163 94 13 121 165 108 67 231 59 162 128 56 65 28 56 220 101 198 205 103 222 105 28 9 235 116 12 8 190 158 143 199 152 213 196 49 53 85 42 252 59 25 114 172 243 249 227 60 65 18 206 72 1 132 227 194 242 25 72 86 86 249 6 248 168 233 18 59 201 109 142 5 18 180 131 248 2 181 233 203 215 0 227 149 139 239 28 17 47 84 119 118 180 183 247 156 22 54 195 88 248 209 206 238 42 125 89 79 41 112 164 120 36 214 200 64 28 123 81 102 87 184 60 96 87 215 70 108 126 153 236 117 34 29 99 18 71 72 106 172 237 116 37 227 216 120 18 43 229 38 143 212 194 136 8 173 86 65 216 6 228 136 143 143 15 197 38 120 9 125 72 70 134 44 33 22 122 203 108 146 88 214 40 196 193 23 47 222 19 49 77 108 192 44 106 111 87 42 181 29 61 18 137 90 34 233 233 233 236 208 194 32 98 97 28 35 7 161 188 154 193 186 5 187 198 93 243 113 171 43 177 127 143 27 183 145 142 49 137 35 36 181 217 118 90 211 134 15 95 76 186 153 42 62 194 223 9 2 197 158 240 40 12 23 232 150 242 179 40 125 66 33 155 4 151 216 145 180 65 150 96 149 10 163 227 93 28 80 11 88 213 226 164 90 9 4 68 137 171 189 163 163 20 86 7 98 180 17 135 106 132 28 12 4 221 108 34 207 193 106 218 191 11 203 100 18 11 208 70 58 198 68 109 130 13 199 10 69 22 60 6 221 71 41 120 50 194 68 162 197 64 130 191 93 188 248 18 4 65 32 200 164 214 150 17 4 217 100 13 101 71 210 189 6 153 30 12 88 16 182 188 201 155 131 9 226 8 20 132 44 28 56 148 176 241 182 146 18 64 33 32 23 134 139 99 68 32 152 88 222 140 227 241 196 25 167 8 196 127 35 93 116 138 208 70 192 240 46 164 128 132 124 42 21 74 240 118 243 12 122 11 56 76 238 136 4 127 253 53 184 173 243 24 17 43 107 209 207 97 93 132 102 209 222 147 122 13 234 110 240 146 111 7 7 7 175 17 31 129 181 179 57 169 87 122 70 45 41 5 142 182 20 90 72 3 72 41 160 86 80 230 238 188 250 151 28 8 130 15 33 136 86 16 199 62 72 162 89 176 227 169 208 48 160 16 62 189 153 66 148 152 56 241 20 38 22 130 76 178 113 251 221 136 192 225 1 178 153 64 104 162 8 35 142 175 171 19 128 36 148 250 220 173 226 164 230 50 137 149 206 121 72 154 154 107 107 160 168 213 146 206 210 118 22 0 141 198 98 177 164 192 31 141 134 40 40 28 35 229 32 144 19 164 179 0 114 50 211 36 224 132 184 229 169 111 65 11 55 78 116 78 27 84 232 8 242 241 42 33 142 68 43 89 143 36 21 240 119 54 196 5 139 22 125 13 62 62 210 10 3 201 75 84 7 247 244 202 164 177 210 80 10 72 176 56 105 39 104 145 222 38 5 105 50 244 22 119 19 69 15 85 7 150 53 219 186 202 204 51 176 104 140 156 131 64 10 68 162 163 20 144 11 144 221 66 219 171 176 229 83 17 78 16 214 185 249 149 186 222 198 213 67 199 252 148 64 230 155 6 130 92 92 244 245 123 111 190 217 18 157 25 29 138 173 110 242 162 5 73 134 133 205 210 32 12 206 230 5 73 189 80 12 80 199 101 53 221 221 141 101 101 106 160 40 237 208 18 6 95 15 78 2 92 236 145 142 145 115 0 136 3 159 211 153 79 133 254 56 6 196 54 233 213 21 51 22 112 38 2 161 128 56 41 10 95 6 117 21 44 53 26 151 51 215 66 1 89 226 74 173 85 23 23 189 135 22 37 139 181 108 244 30 226 230 198 132 216 229 15 103 236 190 167 186 183 183 89 221 3 42 171 108 215 130 52 117 34 146 147 130 199 176 15 89 142 145 115 16 8 148 8 27 190 187 142 2 8 140 68 100 139 166 123 130 164 22 122 219 240 231 66 206 4 153 117 150 101 214 70 4 137 115 169 150 120 243 162 221 25 241 172 219 1 198 197 96 208 164 218 50 41 140 142 175 65 50 25 100 53 18 80 85 166 178 237 90 130 192 10 199 39 2 134 195 184 220 131 104 63 4 98 68 16 150 69 111 205 2 18 156 137 68 75 25 8 102 214 167 103 87 209 49 38 190 33 48 213 187 213 12 65 142 242 32 176 235 224 201 187 51 50 120 140 87 254 235 157 105 56 25 169 171 164 82 118 250 169 199 38 167 108 195 85 130 171 141 98 193 231 212 208 237 255 56 12 6 2 91 123 203 217 9 17 133 3 195 189 63 133 7 129 31 121 179 99 76 239 137 254 254 43 150 152 220 106 22 7 242 180 128 113 132 132 192 182 167 221 58 121 247 110 74 42 8 7 12 70 226 226 42 16 37 201 105 64 17 214 64 42 181 99 34 165 88 152 208 186 235 155 47 235 225 159 161 235 255 49 32 123 113 107 78 159 14 40 113 86 126 36 226 35 226 77 199 152 113 244 230 44 87 237 116 249 31 229 184 37 43 120 14 4 57 178 32 120 209 100 228 248 18 48 224 245 194 170 50 9 214 115 123 167 86 75 5 209 70 219 103 203 85 217 87 131 130 7 57 1 89 239 1 226 239 127 33 130 141 68 46 16 60 254 123 139 222 74 68 199 120 129 143 222 209 25 167 166 242 28 33 211 196 73 208 168 123 215 172 89 243 14 121 15 177 172 91 47 161 234 118 46 192 112 5 193 51 18 195 96 252 132 99 92 4 49 163 227 240 4 193 11 143 94 203 9 130 28 213 236 141 66 28 88 231 177 143 146 150 125 156 74 28 239 131 247 131 54 151 148 4 255 67 231 97 168 213 151 97 175 107 199 98 160 194 160 96 12 138 195 16 140 159 126 143 3 65 28 207 226 200 74 166 215 9 210 117 22 73 38 178 43 239 141 199 152 27 89 91 164 232 240 179 9 197 34 241 215 4 50 9 42 226 88 173 180 23 64 146 196 178 133 225 122 117 143 179 184 161 93 167 56 219 245 64 130 171 5 225 2 161 155 225 213 23 6 144 84 3 9 159 66 179 208 116 204 98 123 95 5 230 137 139 112 115 204 19 175 79 13 249 203 188 151 33 171 186 245 106 181 186 177 38 188 241 56 115 30 88 220 109 72 160 225 139 194 163 209 13 77 167 43 189 255 231 197 238 134 211 99 135 213 251 60 72 176 219 241 104 51 16 228 2 27 71 18 154 81 132 93 37 62 15 205 31 22 182 184 119 167 30 231 136 82 248 175 167 147 40 88 203 118 166 147 171 95 95 113 89 255 32 200 54 246 128 66 245 81 23 201 68 72 167 68 6 118 106 137 149 59 202 182 30 103 144 117 119 219 132 47 191 74 175 222 159 116 4 172 56 122 241 36 217 25 48 82 61 218 14 104 117 160 80 46 231 97 118 67 92 150 226 234 220 80 102 32 5 70 231 19 148 213 243 120 139 152 10 205 47 145 135 122 117 226 171 44 147 254 36 238 53 232 203 164 54 219 170 73 191 158 247 157 55 154 113 67 113 66 146 65 122 166 140 134 83 40 138 18 156 38 208 205 186 40 46 171 77 87 9 193 3 164 0 207 78 240 198 147 209 217 170 105 56 231 188 253 61 157 111 72 200 227 235 197 226 133 101 18 214 172 153 25 47 110 108 212 131 62 73 58 123 104 170 67 117 98 198 195 60 16 99 52 25 92 32 248 60 225 44 232 237 19 97 76 71 23 72 219 46 196 249 251 20 143 193 90 197 227 235 65 99 171 192 250 169 207 72 165 205 120 31 188 184 91 207 155 113 156 185 75 104 168 0 4 141 230 135 40 70 231 89 36 234 236 192 65 174 49 2 67 34 96 213 144 40 131 161 168 112 170 27 35 228 79 235 167 29 73 194 99 51 216 117 103 213 233 51 221 53 3 204 56 223 41 204 174 178 24 142 98 244 30 170 2 16 59 152 198 183 200 152 159 69 142 5 180 243 127 95 223 11 36 171 86 184 56 82 227 126 133 199 152 85 252 65 1 152 113 240 226 30 102 156 207 38 157 78 55 64 101 175 13 5 3 105 48 138 86 50 27 95 8 28 220 68 190 63 136 155 99 129 164 240 99 164 74 253 238 101 60 43 128 118 77 28 120 74 64 94 124 160 25 119 53 60 157 238 218 66 184 64 156 163 235 77 113 75 226 82 137 227 47 235 193 243 117 55 55 199 198 54 39 24 60 143 49 241 192 3 15 7 82 152 23 31 96 198 221 161 112 56 28 215 148 130 129 168 96 228 187 217 121 16 196 103 82 28 92 254 99 101 53 54 105 108 243 128 99 204 82 118 224 132 167 4 188 25 119 249 39 251 229 154 118 127 255 53 2 193 121 100 197 56 231 112 78 241 40 132 114 88 136 195 68 89 183 205 125 140 41 225 93 7 138 210 176 102 220 225 252 218 215 181 166 224 65 10 240 46 135 71 56 222 247 6 142 98 24 38 58 59 240 228 15 143 49 213 76 99 149 120 28 107 30 224 197 135 54 60 254 126 81 255 181 93 8 178 21 196 106 190 59 28 223 173 7 142 143 104 40 106 135 165 29 116 140 57 216 117 12 206 167 254 235 179 200 253 238 133 54 88 120 138 153 144 194 245 172 174 203 220 67 17 226 180 43 221 24 67 188 184 253 58 164 210 176 32 183 27 241 24 200 59 46 206 27 167 162 35 98 89 173 158 142 110 120 203 49 240 24 83 165 187 108 89 95 71 14 6 226 216 246 119 78 8 246 9 133 86 140 24 52 220 161 204 90 156 2 53 216 60 57 70 207 199 94 201 96 101 55 107 107 200 7 246 54 47 108 44 99 195 29 100 18 141 68 67 143 49 111 60 10 30 4 191 89 166 105 83 74 212 250 42 9 201 147 83 102 7 232 147 78 119 195 165 211 224 179 95 250 46 86 74 27 20 53 234 147 211 60 185 173 211 232 12 217 163 2 98 215 105 128 164 132 4 74 201 159 63 13 174 235 27 24 194 19 68 133 119 39 64 159 218 152 121 26 44 79 55 100 54 13 185 99 197 190 249 132 243 144 101 240 109 150 97 11 187 191 255 6 5 113 176 45 235 216 141 150 127 113 146 217 127 131 46 118 87 151 161 232 92 235 58 186 216 43 2 233 119 125 219 99 140 84 246 15 60 249 224 24 200 50 182 32 6 60 139 226 184 17 219 245 79 0 25 22 165 191 127 44 130 12 65 233 31 83 235 255 5 24 0 173 15 202 119 74 152 115 199 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WAHandlerEditorFiles methodsFor: 'accessing-styles' stamp: 'lr 10/8/2008 09:15'!
mainCss
	^ '/* html */
body {
	color: #002842;
	font-size: 12px;
	font-family: Helvetica, Verdana, Arial, sans-serif;
	background-color: #fbfffa;
}
input, textarea, select {
	color: #002842;
	margin-right: 0.5em;
	font-family: Helvetica, Verdana, Arial, sans-serif;
}
input.text, textarea {
	width: 200px;
}
a {
	color: #008aff;
	text-decoration: none;
}

/* headings */
h1, h2, h3, h4, h5, h6 {
	color: #01598d;
	margin-bottom: 1ex;
	font-weight: normal;
}
table { border: 0; border-spacing: 0 2px; }
td { padding-left: 0; }
th {
	text-align: right;
	padding-right: 1em;
}

/* special */
h1.logo a { 
	width: 200px;
	height: 106px;
	outline: none;
	display: block;
	text-indent: -100em;
	background: url(logo.png) no-repeat;
}
h1.title a {
	color: #01598d;
}
span.unspecified {
	color: #ff7000;
}
a.download {
	background: url(save.png) no-repeat;
	background-position: 0 50%;
	padding-left: 18px;
}

/* walkback */
.walkback th {
	width: 150px;
	text-align: left;
	vertical-align: top;
}'! !

!WAHandlerEditorFiles methodsFor: 'accessing-pictures' stamp: 'lr 5/22/2007 21:52'!
savePng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 0 0 0 0 0 249 67 187 127 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 11 10 13 55 15 158 42 216 191 0 0 0 140 116 69 88 116 67 111 109 109 101 110 116 0 77 101 110 117 45 115 105 122 101 100 32 105 99 111 110 10 61 61 61 61 61 61 61 61 61 61 10 10 40 99 41 32 50 48 48 51 32 74 97 107 117 98 32 39 106 105 109 109 97 99 39 32 83 116 101 105 110 101 114 44 32 10 104 116 116 112 58 47 47 106 105 109 109 97 99 46 109 117 115 105 99 104 97 108 108 46 99 122 10 10 99 114 101 97 116 101 100 32 119 105 116 104 32 116 104 101 32 71 73 77 80 44 10 104 116 116 112 58 47 47 119 119 119 46 103 105 109 112 46 111 114 103 103 138 199 71 0 0 2 132 73 68 65 84 56 203 157 146 77 72 84 97 20 134 159 185 221 241 230 207 228 76 224 181 49 205 145 178 81 108 81 81 52 38 20 184 200 22 69 20 46 66 40 44 130 138 169 193 86 45 42 202 69 17 84 16 6 82 180 40 10 34 176 40 40 106 91 208 34 137 68 138 166 69 153 84 106 134 164 232 220 155 206 253 249 78 11 97 108 178 54 189 155 243 193 225 60 156 247 61 95 224 200 217 227 39 63 91 21 218 216 184 51 9 84 1 91 129 134 160 38 217 208 194 159 63 22 25 206 205 187 231 207 157 224 31 10 52 119 116 237 141 173 172 143 85 151 155 131 171 107 202 58 170 35 133 107 109 207 39 253 45 195 235 222 231 234 195 215 81 226 145 55 203 186 59 239 12 255 21 144 60 125 190 219 157 26 59 236 137 198 168 31 102 218 40 99 129 30 164 173 101 35 203 43 22 115 249 254 11 252 161 62 98 5 227 127 155 239 36 121 44 37 95 70 6 68 68 100 224 115 90 122 211 3 146 186 246 68 18 7 47 72 207 171 47 210 245 244 173 180 158 186 46 239 6 135 229 119 89 150 37 169 142 164 232 134 238 179 180 60 198 196 196 4 225 146 114 180 192 36 133 226 0 208 247 113 20 179 68 231 251 120 134 247 3 159 88 178 168 16 2 0 66 65 65 1 0 186 231 130 40 193 87 138 237 39 110 204 219 177 119 112 2 215 243 185 216 243 146 139 61 47 1 120 124 118 31 200 108 95 3 80 162 80 190 162 235 80 35 0 237 187 119 210 152 88 199 204 140 77 52 164 209 148 88 207 222 214 237 0 236 105 94 129 242 21 34 50 7 16 17 34 145 48 21 101 49 46 29 88 199 205 187 15 136 199 170 208 8 160 17 32 81 95 205 173 123 143 104 219 92 195 142 166 245 20 21 23 229 3 0 44 203 194 52 77 170 163 181 57 72 227 170 229 212 198 42 185 124 251 33 109 155 107 216 181 41 129 105 154 56 142 147 179 168 3 40 165 176 109 27 0 211 52 49 77 147 238 163 133 28 187 218 67 214 245 217 223 82 79 251 182 45 104 154 198 212 212 20 182 109 19 10 133 230 0 134 97 80 89 89 153 23 222 154 134 13 60 187 178 1 0 219 182 113 28 135 233 233 233 121 33 235 0 253 253 253 184 174 155 215 240 60 15 93 215 115 239 63 21 137 68 242 51 240 60 143 116 58 205 200 200 8 153 76 6 17 65 68 48 12 131 161 161 33 66 161 80 174 90 150 133 101 89 249 87 80 74 81 92 92 68 48 24 204 125 18 0 215 117 17 53 11 19 53 123 62 229 251 249 22 194 225 48 165 165 165 68 163 81 0 178 217 44 64 46 237 120 93 28 165 20 241 186 58 148 82 44 137 70 115 150 3 169 142 228 25 224 52 255 167 206 95 147 59 51 76 213 34 98 109 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WAHandlerEditorFiles methodsFor: 'accessing' stamp: 'lr 2/10/2008 15:51'!
selectorsToInclude
	^ #( faviconIco mainCss )! !

!WALibrary methodsFor: '*seaside-development' stamp: 'pmm 4/21/2007 00:11'!
configurationComponent
	self subclassResponsibility! !

WAPainter subclass: #WAPlugin
	instanceVariableNames: 'target requestor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAPlugin commentStamp: 'lr 5/30/2007 22:18' prior: 0!
I am an abstract root class for all plugins. Plugins are an easy way to add or remove additional tools without changing the codebase. To add a new plugin make sure you choose the right superclass so that the tool can detect your code.

The appearance of all plugins, such as icons, has to be configured using CSS.!

WAPlugin subclass: #WADispatcherPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WADispatcherPlugin commentStamp: 'pmm 5/27/2007 07:34' prior: 0!
Abstract root class for all plugins that add an action for an application to the dispatcher editor.!

WADispatcherPlugin subclass: #WAConfigureDispatcherPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAConfigureDispatcherPlugin commentStamp: 'pmm 5/28/2007 23:07' prior: 0!
I display the configuration dialog of an application. See WAApplication >> #configurationComponent!

!WAConfigureDispatcherPlugin methodsFor: 'actions' stamp: 'lr 11/28/2008 16:47'!
execute
	self requestor show: self target configurationComponent! !

!WAConfigureDispatcherPlugin methodsFor: 'testing' stamp: 'lr 5/11/2007 14:03'!
isActive
	^ self target configurationComponent notNil! !

!WAConfigureDispatcherPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 14:02'!
label
	^ 'Configure'! !

!WAConfigureDispatcherPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 14:10'!
priority
	^ 100! !

WADispatcherPlugin subclass: #WACopyDispatcherPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WACopyDispatcherPlugin commentStamp: 'pmm 5/28/2007 23:06' prior: 0!
I make a copy of an application.!

!WACopyDispatcherPlugin methodsFor: 'actions' stamp: 'jf 10/7/2008 01:17'!
execute
	| name |
	name := self requestor
		request: 'Name'
		label: 'add'
		default: self target name.
	name ifNil: [ ^ self ].
	self requestor handler
		register: (self target cloneHandler
			setName: name;
			yourself)! !

!WACopyDispatcherPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 14:02'!
label
	^ 'Copy'! !

!WACopyDispatcherPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 14:11'!
priority
	^ 200! !

WADispatcherPlugin subclass: #WARemoveDispatcherPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WARemoveDispatcherPlugin commentStamp: 'pmm 5/28/2007 23:06' prior: 0!
I remove an application.!

!WARemoveDispatcherPlugin methodsFor: 'actions' stamp: 'lr 2/10/2008 17:23'!
execute
	self requestor handler unregister: self target! !

!WARemoveDispatcherPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 14:02'!
label
	^ 'Remove'! !

!WARemoveDispatcherPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 14:11'!
priority
	^ 300! !

WAPlugin subclass: #WAHaloPlugin
	instanceVariableNames: ''
	classVariableNames: 'EnableSeasideTools'
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAHaloPlugin commentStamp: 'pmm 5/27/2007 07:47' prior: 0!
Abstract root class for all halo tools. They add functionality to the halo toolbar.!

WAHaloPlugin subclass: #WAClassnameHaloPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAClassnameHaloPlugin commentStamp: 'pmm 5/27/2007 17:34' prior: 0!
I display the class name of the component class.!

!WAClassnameHaloPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 11:02'!
priority
	^ 100! !

!WAClassnameHaloPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:58'!
renderContentOn: html
	html div class: self cssClass; with: self target className! !

!WAHaloPlugin class methodsFor: 'initialization' stamp: 'lr 5/11/2007 01:22'!
initialize
	EnableSeasideTools := true! !

!WAHaloPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 12:22'!
renderContentOn: html
	html div
		class: self cssClass;
		with: [ super renderContentOn: html ]! !

WAHaloPlugin subclass: #WAModeHaloPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAModeHaloPlugin commentStamp: 'pmm 5/27/2007 17:35' prior: 0!
I control the rendering modes of the halo.!

!WAModeHaloPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 11:02'!
priority
	^ 900! !

!WAModeHaloPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:58'!
renderContentOn: html
	html div class: self cssClass; with: [
		html text: '['.
		self requestor modes
			do: [ :each |
				html anchor
					class: 'active' if: self requestor mode = each;
					title: (self labelForSelector: each allButLast);
					callback: [ self requestor mode: each ];
					with: each first asUppercase ]
			separatedBy: [ html text: '|' ].
		html text: ']' ]! !

WAHaloPlugin subclass: #WAStylesHaloPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAStylesHaloPlugin commentStamp: 'pmm 5/27/2007 17:35' prior: 0!
I open the style editor on the component class.!

!WAStylesHaloPlugin methodsFor: 'actions' stamp: 'pmm 11/14/2008 22:26'!
execute
	EnableSeasideTools
		ifTrue: [ self open: (WAPluggableTool on: (WAViewer on: self target)) ]
		ifFalse: [ Browser fullOnClass: self target class selector: #style ]! !

!WAStylesHaloPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:56'!
label
	^ 'Styles'! !

!WAStylesHaloPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 11:02'!
priority
	^ 700! !

!WAStylesHaloPlugin methodsFor: 'accessing' stamp: 'pmm 5/16/2007 16:24'!
tooltip
	^ 'CSS Style Editor'! !

!WAPlugin class methodsFor: 'instance-creation' stamp: 'lr 5/11/2007 14:18'!
allSubclassesOn: aTargetObject for: aRequestorObject
	| plugins |
	plugins := self allSubclasses
		collect: [ :each | each on: aTargetObject for: aRequestorObject ].
	^ plugins asSortedCollection! !

!WAPlugin class methodsFor: 'instance-creation' stamp: 'lr 5/11/2007 13:50'!
on: aTargetObject for: aRequestorObject
	^ self basicNew initializeTarget: aTargetObject requestor: aRequestorObject! !

!WAPlugin methodsFor: 'comparing' stamp: 'lr 5/11/2007 10:51'!
<= aPlugin
	^ self priority <= aPlugin priority! !

!WAPlugin methodsFor: 'accessing' stamp: 'lr 9/25/2008 17:56'!
cssClass
	"Answer a CSS class that will be applied to an automatically rendered link."

	^ (self class name allButFirst: 2) asLowercase! !

!WAPlugin methodsFor: 'actions' stamp: 'lr 5/11/2007 10:50'!
execute
	"Execute the receiving plugin."! !

!WAPlugin methodsFor: 'initialization' stamp: 'lr 5/11/2007 13:50'!
initializeTarget: aTargetObject requestor: aRequestorObject
	target := aTargetObject.
	requestor := aRequestorObject! !

!WAPlugin methodsFor: 'testing' stamp: 'lr 10/28/2007 14:42'!
isActive
	"Answer wheter the plugin is usable with the current target."

	^ true! !

!WAPlugin methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
label
	"Answer the menu label of the plugin."

	^ self printString! !

!WAPlugin methodsFor: 'actions' stamp: 'jf 10/19/2008 15:47'!
open: aComponent
	"Replace the current page with aComponent."

	self session inNewRenderLoopCall:
		(aComponent
			addDecoration: (WAWindowDecoration new
				cssClass: self cssClass;
				title: self label;
				yourself);
			yourself)! !

!WAPlugin methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
priority
	"Answer a number used to sort the receiver. A lower number means it appears earlier on."

	^ 0! !

!WAPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:59'!
renderContentOn: html
	"A default render method to display the interface of the receiving plugin. Might be overriden with specific behavior in subclasses."

	html anchor
		title: self tooltip;
		class: self cssClass;
		callback: [ self execute ];
		with: self label! !

!WAPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 12:02'!
rendererClass
	^ WARenderCanvas! !

!WAPlugin methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
requestor
	"Answer the requestor component the plugin is working on."

	^ requestor! !

!WAPlugin methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
target
	"Answer the target object the plugin is working on."

	^ target! !

!WAPlugin methodsFor: 'accessing' stamp: 'lr 10/28/2007 14:42'!
tooltip
	"Answer a tooltip string that is displayed on the plugin link or button."

	^ nil! !

WAPlugin subclass: #WAToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAToolPlugin commentStamp: 'pmm 5/27/2007 07:47' prior: 0!
Abstract root class for all development tool bar tools.!

WAToolPlugin subclass: #WAConfigureToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAConfigureToolPlugin commentStamp: 'pmm 5/27/2007 18:33' prior: 0!
I display the configuration dialog for the currently active application!

!WAConfigureToolPlugin methodsFor: 'actions' stamp: 'pmm 11/14/2008 22:26'!
execute
	self open: (WAPluggableTool on: self application configurationComponent)! !

!WAConfigureToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:16'!
label
	^ 'Configure'! !

!WAConfigureToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:56'!
priority
	^ 200! !

WAToolPlugin subclass: #WADeprecationToolPlugin
	instanceVariableNames: 'filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WADeprecationToolPlugin commentStamp: 'pmm 5/27/2007 18:33' prior: 0!
I display deprecation warnings.!

!WADeprecationToolPlugin methodsFor: 'actions' stamp: 'pmm 10/11/2008 18:27'!
execute
	self open: (WADeprecation on: filter)! !

!WADeprecationToolPlugin methodsFor: 'initialization' stamp: 'lr 9/25/2008 11:24'!
initializeTarget: aTargetObject requestor: aRequestorObject
	super initializeTarget: aTargetObject requestor: aRequestorObject.
	self session addFilter: (filter := WADeprecatedToolFilter new)! !

!WADeprecationToolPlugin methodsFor: 'testing' stamp: 'lr 9/25/2008 15:14'!
isActive
	^ filter notifications notEmpty! !

!WADeprecationToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:36'!
label
	^ 'Deprecated'! !

!WADeprecationToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:59'!
priority
	^ 700! !

WAToolPlugin subclass: #WANewSessionToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WANewSessionToolPlugin commentStamp: 'pmm 5/27/2007 18:32' prior: 0!
I create a new session.!

!WANewSessionToolPlugin class methodsFor: 'accessing' stamp: 'pmm 5/10/2007 22:18'!
title
	^'New Session'! !

!WANewSessionToolPlugin methodsFor: 'actions' stamp: 'jf 10/18/2008 17:39'!
execute
	self session unregister.
	self requestContext redirectTo: self application baseUrl! !

!WANewSessionToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:26'!
label
	^ 'New Session'! !

!WANewSessionToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:56'!
priority
	^ 100! !

WAToolPlugin subclass: #WATerminateToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WATerminateToolPlugin commentStamp: 'pmm 5/27/2007 18:32' prior: 0!
I try to terminate the process handling this session. This can work of you're at 100% CPU.!

!WATerminateToolPlugin methodsFor: 'testing' stamp: 'jf 9/11/2008 14:55'!
isActive
	^ self session sessionAllowTermination! !

!WATerminateToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:29'!
label
	^ 'Terminate'! !

!WATerminateToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:57'!
priority
	^ 600! !

!WATerminateToolPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:59'!
renderContentOn: html
	html anchor
		url: (html context actionUrl
			withParameter: 'terminate');
		with: self label! !

WAToolPlugin subclass: #WATimingToolPlugin
	instanceVariableNames: 'filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WATimingToolPlugin commentStamp: 'pmm 5/27/2007 18:31' prior: 0!
I display render and callback times.!

!WATimingToolPlugin methodsFor: 'initialization' stamp: 'lr 9/25/2008 10:46'!
initializeTarget: aTargetObject requestor: aRequestorObject
	super initializeTarget: aTargetObject requestor: aRequestorObject.
	self session addFilter: (filter := WATimingToolFilter new)! !

!WATimingToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:59'!
priority
	^ 900! !

!WATimingToolPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:59'!
renderContentOn: html
	html span
		title: 'Callback Time';
		with: filter previousTiming.
	html text: '/'.
	html span
		title: 'Render Time';
		with: filter currentTiming.
	html text: ' ms'! !

WAToolPlugin subclass: #WAToggleHalosToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAToggleHalosToolPlugin commentStamp: 'pmm 5/27/2007 18:31' prior: 0!
I toggle halos on and off.!

!WAToggleHalosToolPlugin methodsFor: 'actions' stamp: 'lr 5/11/2007 13:54'!
execute
	 self requestor toggleHalos! !

!WAToggleHalosToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:56'!
label
	^ 'Toggle Halos'! !

!WAToggleHalosToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:56'!
priority
	^ 300! !

WAToolPlugin subclass: #WAValidateToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAValidateToolPlugin commentStamp: 'pmm 5/27/2007 18:31' prior: 0!
I validate and XHTML page by sending it to the W3C validator. I only work if the website is publically available.!

!WAValidateToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:30'!
label
	^ 'XHTML'! !

!WAValidateToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:59'!
priority
	^ 800! !

!WAValidateToolPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:59'!
renderContentOn: html
	html anchor
		title: 'Validate XHTML';
		url: 'http://validator.w3.org/check/referer';
		with: self label! !

!WAFileHandler methodsFor: '*seaside-development' stamp: 'lr 2/10/2008 15:45'!
configurationComponent
	^ WAFileHandlerEditor on: self! !

!WAUserConfiguration methodsFor: '*seaside-development' stamp: 'jf 8/4/2008 16:18'!
clearValueForAttribute: anAttribute
	expressions removeKey: anAttribute key ifAbsent: []! !

!WAUserConfiguration methodsFor: '*seaside-development' stamp: 'jf 7/21/2008 23:53'!
configurationComponent
	^ WAUserConfigurationEditor on: self! !

!WAUserConfiguration methodsFor: '*seaside-development' stamp: 'avi 3/23/2004 14:51'!
overrideAttribute: anAttribute
	self takeValue: (self valueForAttribute: anAttribute) forAttribute: anAttribute! !
WAHalo initialize!
WADispatcherEditor initialize!
WADispatcherViewer initialize!
WAHaloPlugin initialize!
